local lang = {
  ["abort"] = "Abbruch",
  ["actions"] = "Aktionen",
  ["activities"] = "Aktivitäten",
  ["activity"] = "Aktivität",
  ["aggregation"] = "Aggregierung",
  ["all"] = "alle",
  ["any"] = "beliebige",
  ["application"] = "Applikation",
  ["applications"] = "Applikationen",
  ["arp"] = "ARP",
  ["as"] = "AS",
  ["as_number"] = "AS Nummer",
  ["asn"] = "ASN",
  ["begin"] = "Anfang",
  ["breakdown"] = "Ausfall",
  ["bridge"] = "Bridge",
  ["broadcast_traffic"] = "Broadcast Datenverkehr",
  ["bytes"] = "Bytes",
  ["change_number_of_rows"] = "Anzahl der Zeilen ändern",
  ["chart"] = "Tabelle",
  ["client"] = "Client",
  ["clone"] = "Klonen",
  ["close"] = "schliessen",
  ["countries"] = "Länder",
  ["date_from"] = "Anfangs Datum/Zeit:",
  ["date_to"] = "End Datum/Zeit:",
  ["day"] = "Tag",
  ["define"] = "definieren",
  ["delete"] = "Löschen",
  ["difference"] = "Unterschied",
  ["disabled"] = "Deaktiviert",
  ["dns"] = "DNS",
  ["download"] = "Herunterladen",
  ["download_x"] = "%{what} herunterladen",
  ["downloaders"] = "Download Volumen",
  ["duration"] = "Dauer",
  ["egress"] = "Ausgang",
  ["empty"] = "Leer",
  ["end"] = "Ende",
  ["enterpriseOnly"] = "Diese Funktion ist nur in der ntopng Enterprise Edition verfügbar",
  ["error"] = "Fehler",
  ["error_no_search_results"] = "Keine Ergebnisse gefunden. Bitte ändern Sie Ihre Suchkriterien.",
  ["error_not_granted"] = "Anfrage nicht gewährt",
  ["error_rrd_cannot_complete_dump"] = "Zeitserien-Dump der lokalen Hosts kann nicht abgeschlossen werden. Festplatte langsam oder zu viele lokale Hosts?",
  ["error_rrd_low_resolution"] = "Sie möchten Daten mit einer niedrigeren Auflösung als der auf RRD verfügbaren abrufen, was zu ungültigen Daten führt.<br>Wenn Sie dennoch Daten mit einer solchen Granularität wünschen, stellen Sie bitte <a href=\"%{prefs}\">Protokoll/Netzwerk Zeitreihe</a> preferences",
  ["errors"] = "Fehler",
  ["expired_csrf"] = "Die angeforderte Aktion konnte nicht ausgeführt werden, da die Seite nicht mehr aktuell ist. Bitte laden Sie die Seite neu und führen Sie die Aktion erneut aus.",
  ["export"] = "Export",
  ["factory_reset"] = "Factory Reset",
  ["filter"] = "Filter",
  ["filter_by"] = "Filtern nach",
  ["fingerprint_note"] = "Anwendungsname wird nur gesetzt, wenn ntopng für den Empfang eines eBPF-Feeds über ZMQ konfiguriert ist",
  ["flow"] = "Datenfluss",
  ["flow_search_criteria"] = "Suchskriterium Datenfluss",
  ["flow_search_from_aggregated"] = "(Aggregiert)",
  ["flow_search_results"] = "Suchsergebnisse Datenfluss",
  ["flows"] = "Datenflüsse",
  ["from"] = "von",
  ["gateway"] = "Gateway",
  ["host"] = "Host %{host}",
  ["hour"] = "Stunde",
  ["http"] = "HTTP",
  ["icmp"] = "ICMP",
  ["incomingflows"] = "Anzahl einkommende Datenflüsse",
  ["info"] = "Info",
  ["ingress"] = "Eingang",
  ["interface"] = "Schnittstelle",
  ["interface_ifname"] = "Schnittstelle %{ifname}",
  ["interfaces"] = "Schnittstellen",
  ["ip_address"] = "IP Adresse",
  ["ipv4"] = "IPv4",
  ["ipv6"] = "IPv6",
  ["key"] = "Schlüssel",
  ["layer_2"] = "Layer 2",
  ["legenda"] = "Legende",
  ["local_traffic"] = "Lokaler Datenverkehr",
  ["mac_address"] = "MAC Adresse",
  ["max_rate"] = "Max Rate",
  ["model"] = "Model",
  ["month"] = "Monat",
  ["mtu"] = "MTU",
  ["name"] = "Name",
  ["netmask"] = "Netmask",
  ["networks"] = "Netzwerke",
  ["next"] = "nächster",
  ["noTraffic"] = "Für die angegebene Datums/Uhrzeitauswahl wurde kein Datenverkehr gemeldet",
  ["no_results_found"] = "Keine Resultate gefunden",
  ["notes"] = "Notizen:",
  ["operating_systems"] = "Betriebssystem",
  ["os"] = "OS",
  ["other"] = "Andere",
  ["outgoingflows"] = "Anzahl ausgehende Datenflüsse",
  ["overview"] = "Übersicht",
  ["packets"] = "Pakete",
  ["peers"] = "Peers",
  ["percentage"] = "Prozent",
  ["pkts"] = "Pkts",
  ["port"] = "Port",
  ["ports"] = "Ports",
  ["previous"] = "vorherig",
  ["protocol"] = "Protokoll",
  ["protocols"] = "Protokolle",
  ["purged_error_message"] = "Sehr wahrscheinlich ist es abgelaufen und %{product} hat es aus dem Speicher gelöscht. Sie können die Einstellungen für das Leerlaufzeitlimit für die Bereinigung über das Menü <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Einstellungen</a>.",
  ["quotas"] = "Quoten",
  ["received"] = "erhalten",
  ["refresh"] = "Aktualisieren",
  ["remote_networks"] = "Externe Netzwerke",
  ["remove"] = "entfernen",
  ["save"] = "speichern",
  ["save_configuration"] = "Konfiguration speichern",
  ["save_settings"] = "Einstellungen speichern",
  ["search_host"] = "Suche",
  ["seen_since"] = "gesehen seit",
  ["sent"] = "gesendet",
  ["server"] = "Server",
  ["similarity"] = "Ähnlichkeit",
  ["speed"] = "Geschwindigkeit",
  ["status"] = "Status",
  ["summary"] = "Zusammenfassung",
  ["talkers"] = "Talkers",
  ["tcp_flags"] = "TCP Kennzeichnung",
  ["throughput"] = "Datendurchsatz",
  ["time"] = "Zeit",
  ["timeframe"] = "Zeitfenster",
  ["tls_certificate"] = "TLS Zertifikat",
  ["today"] = "Heute",
  ["total"] = "Total",
  ["traffic"] = "Datenverkehr",
  ["traffic_policy"] = "Datenverkehr Policy",
  ["undo"] = "Rücksetzen",
  ["unknowers"] = "Unknown Traffic Volume",
  ["unknown"] = "Unbekannt",
  ["unlimited"] = "unlimitiert",
  ["uploaders"] = "Upload Volumen",
  ["version"] = "Deine Version ist %{vers}.",
  ["vlan"] = "VLAN",
  ["warning"] = "Warnung",
  ["week"] = "Woche",
  ["welcome"] = "Willkommen",
  ["about"] = {
    ["about"] = "Über",
    ["about_x"] = "Über %{product}",
    ["built_on"] = "Aufgebaut auf",
    ["copyright"] = "Urheberrecht",
    ["cpu_load"] = "CPU laden",
    ["last_log"] = "Letzte Protokollspur",
    ["licence"] = "Lizenz",
    ["licence_expires_in"] = "Lizenz verfällt in %{time}",
    ["licence_generation"] = "Klicken Sie auf die obige URL, um Ihre Lizenz für die Professional-Version zu generieren, oder <br> erwerben Sie eine Lizenz unter <a href=\"%{purchase_url}\">Online Shop</a>. Wenn Sie eine No-Profit-, Forschungs- oder Bildungs<br>Institution sind, lesen Sie bitte <a href=\"%{universities_url}\"></a>.",
    ["maintenance_expired"] = "%{product} Unterhalt ist verfallen",
    ["maxmind"] = "Dieses Produkt beinhaltet GeoDB Data kreirt von <a class='ntopng-external-link' href=\"%{maxmind_url}\">MaxMind <i class=\"fas fa-external-link-alt\"></i></a> und <a class='ntopng-external-link' href='https://db-ip.com'>DB-IP <i class=\"fas fa-external-link-alt\"></i></a>.",
    ["ntop_blog"] = "ntop Blog",
    ["platform"] = "Plattform",
    ["ram_memory"] = "RAM",
    ["readme_and_manual"] = "Benutzer Handbuch",
    ["report_issue"] = "Ein Problem melden",
    ["runtime_status"] = "Status Laufzeit",
    ["save_licence"] = "Lizenz speichern",
    ["specify_licence"] = "Geben Sie hier Ihre ntopng-Lizenz an",
    ["startup_line"] = "Start Line",
    ["system_id"] = "System ID",
    ["upgrade_to_professional"] = "Upgrade auf Pro/Enterprise-Version",
    ["uptime"] = "Betriebszeit",
    ["version"] = "Version",
  },
  ["activities_page"] = {
    ["host_activity"] = "Host Aktivität",
  },
  ["alert_messages"] = {
    ["a_new_device_has_connected"] = "Neues Gerät <a href=\"%{url}\">%{device}</a> hat sich mit dem Netzwerk verbunden.",
    ["anomalous_tcp_flags"] = "%{entity} has %{sent_or_rcvd} zu viele TCP RST-Flags vs. SYN [Verhältnis: %{ratio}%%]",
    ["attack_mitigation_via_snmp_failure"] = "Schnittstelle nicht eingestellt <a href=\"%{port_url}\">%{port}</a> Admin-Status auf SNMP-Gerät <a href=\"%{url}\">%{device}</a> nach %{admin_down}: %{granularity} <b>%{metric}</b> durchquert von %{entity} [%{value} %{op} %{threshold}]. Stellen Sie sicher, dass das SNMP-Gerät eine (gültige) Schreib-Community konfiguriert hat.",
    ["attack_mitigation_via_snmp_success"] = "Schnittstelle <a href=\"%{port_url}\">%{port}</a> admin status on SNMP device <a href=\"%{url}\">%{device}</a> set to %{admin_down}: %{granularity} <b>%{metric}</b> überschritten von %{entity} [%{Wert} %{Op} %{threshold}]",
    ["broadcast_domain_info"] = "Es ist unwahrscheinlich, dass ARP-Verkehr zwischen diesen IPs zu sehen ist, da sie scheinbar zu verschiedenen Broadcast-Domänen gehören. Prüfen Sie die Konfigurationen von Hosts und Netzwerken.",
    ["broadcast_domain_too_large"] = "ARP-Verkehr von <a href=\"%{src_mac_url}\">%{src_mac}</a>/<a href=\"%{spa_url}\">%{spa}</a> zu <a href=\"%{dst_mac_url}\">%{dst_mac}</a>/<a href=\"%{tpa_url}\">%{tpa}</a> erkannt.",
    ["contacted_peers"] = "Zu viele Peers von %{host} %{host_category} kontaktiert. Als Client: [%{value_cli} > %{dyn_threshold_cli}]. Als Server: [%{value_srv} > %{dyn_threshold_srv}].",
    ["contacted_peers_as_cli"] = "Zu viele Peers als Client kontaktiert von %{host} %{host_category} [%{value_cli} > %{dyn_threshold_cli}].",
    ["contacted_peers_as_srv"] = "Zu viele Peers als Server kontaktiert von %{host} %{host_category} [%{value_srv} > %{dyn_threshold_srv}].",
    ["device_has_connected"] = "Das Gerät <a href=\"%{url}\">%{device}</a> hat sich mit dem Netzwerk verbunden.",
    ["device_has_disconnected"] = "Das Gerät <a href=\"%{url}\">%{device}</a> hat die Verbindung zum Netzwerk getrennt.",
    ["flow_flood_attacker"] = "%{entity}%{host_category} flutet das Netzwerk [%{value} &gt; %{threshold} Datenflüsse gesendet]",
    ["flow_flood_victim"] = "%{entity}%{host_category} ist unter einer Flutungsattacke [%{value} &gt; %{threshold} Datenflüsse erhalten]",
    ["host_alert_countries_contacts"] = "Zu viele Länder kontaktiert von %{entity} [%{value} &gt; %{threshold} Länder]",
    ["host_entity"] = "Host %{entity_value}",
    ["host_log"] = "Log-Eintrag von <a href=\"%{url}\">%{host}</a> (%{facility}) %{line}",
    ["host_pool_has_connected"] = "Der Host-Pool <a href=\"%{url}\">%{pool}</a> hat sich mit dem Netzwerk verbunden.",
    ["host_pool_has_disconnected"] = "Der Host-Pool <a href=\"%{url}\">%{pool}</a> hat die Verbindung zum Netzwerk getrennt.",
    ["host_remote_to_remote"] = "Remote/externe Host <a href=\"%{url}\">%{ip}</a> %{mac} einen entfernten Host kontaktiert hat. Remote-zu-Remote-Flüsse, die vom <a href=\"%{flow_alerts_url}\">Seite für Datenfluss-Alarme</a>.",
    ["http_download_failed"] = "Durchsatzprüfung fehlgeschlagen",
    ["iface_alerts_dropped"] = "Schnittstelle <a href=\"%{url}\">%{iface}</a> verwirft Alarme. Wahrscheinlich werden zu viele Alarme erzeugt, oder die Empfänger sind zu langsam.",
    ["influxdb_dropped_points"] = "Enträge verworfen. Konnten nicht an \"%{influxdb}\" gesendet werden.",
    ["influxdb_migration_msg"] = "Sie haben eine grosse Anzahl an lokalen Hosts. Betrachten Sie <a href='%{url}'>von RRD zu InfluxDB</a> für die Speicherung von Zeitreihen zu wechseln, um die Leistung zu verbessern.",
    ["influxdb_partial_write"] = "Dies kann behoben werden, indem Sie \"max-values-per-tag = 0\" in der InfluxDB Servereinstellung.",
    ["influxdb_write_error"] = "Es gab einen Fehler beim Senden von Zeitreihendaten an \"%{influxdb}\": %{err}",
    ["interface_entity"] = "Schnittstelle %{entity_value}",
    ["ip_outside_dhcp_range_router_ip"] = "[Router: <a href=\"%{router_url}\">%{router_ip}</a>]",
    ["ip_outsite_dhcp_range"] = "Gerät <a href=\"%{client_url}\">%{client_mac}</a> hat die IP Adresse <a href=\"%{client_ip_url}\">%{client_ip}</a> die ausserhalb des <a href=\"%{dhcp_url}\">konfigurierten DHCP-Bereichs liegt, erhalten</a>. [Sender: <a href=\"%{sender_url}\">%{sender_mac}</a>]",
    ["lldp_arc_added"] = "Neue Verbindung zwischen SNMP-Geräten hinzugefügt <a href=\"%{url1}\">%{node1}</a> und <a href=\"%{url2}\">%{node2}</a>",
    ["lldp_arc_removed"] = "Entfernte Verbindung zwischen SNMP-Geräten <a href=\"%{url1}\">%{node1}</a> und <a href=\"%{url2}\">%{node2}</a>",
    ["mac_ip_association_change"] = "IP %{ip} änderte ihre Zuordnung von <a href=\"%{old_mac_url}\">%{old_mac}</a> nach <a href=\"%{new_mac_url}\">%{new_mac}</a>",
    ["measurement_too_high_msg"] = "Messung zu hoch für %{host} %{numeric_ip} [%{am_value} %{unit} > %{threshold} %{unit}].",
    ["measurement_too_low_msg"] = "Messung zu tief für %{host} %{numeric_ip} [%{am_value} %{unit} < %{threshold} %{unit}].",
    ["misbehaving_flows_ratio"] = "%{entity} hat %{sent_or_rcvd} zu viele fehlerhafte Flüsse vs. Gesamtflüsse [Ratio: %{ratio}%%]",
    ["network_entity"] = "Netzwerk %{entity_value}",
    ["nfq_flushed"] = "Schnittstelle <a href=\"%{url}\">%{name}</a> Pakete Warteschlange geleert. Warteschlange %{pct}%% voll mit %{tot} Paketen und %{dropped} verworfen Paketen.",
    ["no_influxdb"] = "Bitte <A HREF=\"%{url}\">aktivieren Sie den Zeitseriendump in der InfluxDB </A> und laden dann diese Seite neu",
    ["ntopng_anomalous_termination"] = "Gestartet nach aussergewöhnlicher Beendigung (<a href=\"%{url}\">Problemreport</a>)",
    ["ntopng_start"] = "Gestartet",
    ["ntopng_stop"] = "Gestoppt",
    ["ntopng_update"] = "Nach Software-Update gestarted",
    ["open_files_limit_too_small"] = "Ntopng hat festgestellt, dass die maximale Anzahl von Dateien, die MySQL öffnen kann, möglicherweise zu klein ist. Dies kann zu Flussdatenverlusten aufgrund von Fehlern wie [Keine Ressourcen mehr beim Öffnen der Datei './ntopng/flowsv6#P#p22.MYD' (Errcode: 24 - Zuviele offene Dateien)][23]. Stellen Sie sicher, dass Sie open_files_limit erhöhen, oder, wenn Sie diese Warnung einfach ignorieren wollen, deaktivieren Sie die Prüfung in den Voreinstellungen.",
    ["periodic_activity_not_executed"] = "Periodische Aktivität \"%{script}\" steht in der Warteschlange, wurde aber noch nicht ausgeführt. Kein Thread zur Ausführung verfügbar.  [Pending since %{pending_since}]",
    ["periodicity_update_ended"] = "Periodischer Datenfluss beendet: %{host_info1}  <i class=\"fas fa-exchange-alt fa-lg\" aria-hidden=\"true\" data-original-title=\"\" title=\"\"></i> %{host_info2} [Application: %{l7_proto}] %{info}",
    ["periodicity_update_new"] = "Datenfluss %{host_info1}  <i class=\"fas fa-exchange-alt fa-lg\" aria-hidden=\"true\" data-original-title=\"\" title=\"\"></i> %{host_info2} [Application: %{l7_proto}] %{info} ist jetzt periodisch (freq. %{frequency} sec)",
    ["ping_host_unreachable_v3"] = "Host %{host} %{numeric_ip} ist nicht erreichbar.",
    ["potentially_dangerous_protocol_description"] = "Dieser Fluss kann für das Netzwerk schädlich sein, weil ein veraltetes oder anfälliges Protokoll verwendet wird.",
    ["proto_bytes_quotas"] = "%{proto} Bytes",
    ["proto_time_quotas"] = "%{proto} Zeit",
    ["remote_to_remote"] = "Remote/externer %{entity}%{host_category} hat remote/externen Host kontaktiert",
    ["shell_script_executed"] = "Shell script '%{script_exec_comm}' ausgeführt als Reaktion auf einen Alarm: '%{alert_type}'",
    ["slow_periodic_activity"] = "Periodic activity \"%{script}\" läuft zu lange [mehr als %{max_duration}] oder wird zu spät ausgeführt (in Warteschlange blockiert).",
    ["slow_purge"] = "<a href=\"%{url}\">Löschen von Leerlaufeinträgen in der Hash-Tabelle</a> bei %{iface} ist zu langsam. Dies kann zu hoher Speicherauslastung, Verlust der Datengenauigkeit und fehlenden Alarmen führen. [%{idle}%% &gt %{max_idle}%%]",
    ["speedtest_failed"] = "Ausführung des Geschwindigkeit-Tests ist fehlgeschlagen",
    ["subject_quota_exceeded"] = "Host Pool <a href=\"%{url}\">%{pool}</a> überschreitet %{subject} Quote [%{value} &gt; %{quota}]",
    ["syn_flood_attacker"] = "%{entity}%{host_category} ist ein SYN Fluter [%{value} &gt; %{threshold} SYN gesendet]",
    ["syn_flood_victim"] = "%{entity}%{host_category} ist unter einer SYN Fluter Attacke [%{value} &gt; %{threshold} SYN erhalten]",
    ["syn_scan_attacker"] = "%{entity}%{host_category} ist ein SYN Scan Angreifer [%{value} &gt; %{threshold} SYN gesendet]",
    ["syn_scan_victim"] = "%{entity}%{host_category} ist unter einer SYN Scan Attacke [%{value} &gt; %{threshold} SYN erhalten]",
    ["test_failed"] = "Test fehlgeschlagen",
    ["threshold_crossed"] = "%{granularity} <b>%{metric}</b> gekreuzt von %{entity}%{host_category} [%{value} %{op} %{threshold}]",
    ["too_many_drops"] = "%{iface} hat zu viele verworfene Pakete [&gt %{max_drops}%%]",
    ["too_many_flows"] = "%{iface} hat zu viele Ströme. Bitte erweitern Sie die %{option} Kommandozeilenoption.",
    ["too_many_flows_details"] = "Wollen Sie die aktuelle Anzahl der maximalen Flows verdoppeln?",
    ["too_many_flows_err"] = "Kann max. Flows nicht verdoppeln. Bitte stellen Sie -X in der Konfigurationsdatei ein und starten Sie ntopng neu.",
    ["too_many_flows_title"] = "Verdoppeln sie die Anzahl maximale Durchflüsse",
    ["too_many_hosts"] = "%{iface} hat zu viele Hosts. Bitte erweitern Sie die %{option} Kommandozeilenoption.",
    ["too_many_hosts_details"] = "Möchten Sie die aktuelle Anzahl der maximalen Hosts verdoppeln?",
    ["too_many_hosts_err"] = "Kann max. Hosts nicht verdoppeln. Bitte stellen Sie -X in der Konfigurationsdatei ein und starten Sie ntopng neu.",
    ["too_many_hosts_title"] = "Verdoppeln Sie die max. Anzahl Hosts",
    ["x_alerts"] = "%{num} Alarme",
  },
  ["alerts_dashboard"] = {
    ["alert_counts"] = "Anzahl",
    ["alert_duration"] = "Dauer",
    ["alert_severity"] = "Schwierigkeitsgrad",
    ["alert_type"] = "Typ",
    ["alerts_dashboard"] = "Alarme Dashboard",
    ["all_hosts"] = "Alle Hosts",
    ["blacklisted_flow"] = "Blacklisted Flüsse",
    ["blocked_flow"] = "Blockierte Flüsse",
    ["custom_period"] = "Custom Periode",
    ["engaged_for_longest"] = "Past Alerts Engaged for Longest",
    ["error"] = "Error",
    ["five_mins"] = "Letzten 5 Minuten",
    ["flow_alert_origins"] = "Ursprungs Flow Alarm",
    ["flow_alert_targets"] = "Flow Alarm Ziele",
    ["flow_misbehaviour"] = "Fluss Fehlverhalten",
    ["host_alert_countries_contacts"] = "Länderkontakte Benachrichtigung",
    ["info"] = "Info",
    ["involving_msg"] = "Involvierte Flow Alarme",
    ["last_day"] = "Letzter Tag",
    ["last_hour"] = "Letzte Stunde",
    ["last_minute"] = "Letzte Minute",
    ["local_only"] = "Nur lokale Hosts",
    ["local_origin_remote_target"] = "Lokaler Ursprung - Remote Ziel",
    ["no_alert"] = "Keine Alarme",
    ["no_alerts"] = "Keine Alarme",
    ["none"] = "None",
    ["not_engaged"] = "Nicht besetzt",
    ["one_day"] = "Letzter Tag",
    ["one_hour"] = "Letzte Stunde",
    ["one_min"] = "Letzte Minute",
    ["remote_only"] = "Nur Remote Hosts",
    ["remote_origin_local_target"] = "Remote Ursprung - Lokales Ziel",
    ["search_criteria"] = "Dashboard Settings",
    ["starting_on"] = "beginnend am",
    ["submit"] = "Dashboard aktualisieren",
    ["suspicious_activity"] = "Verdächtige Aktivitäten",
    ["tcp_syn_flood"] = "TCP SYN Flut",
    ["threashold_cross"] = "Schwelle überschritten",
    ["total_alerts"] = "Total Alarme",
    ["trailing_msg"] = "Zeit Fenster",
    ["warning"] = "Warning",
  },
  ["alerts_thresholds_config"] = {
    ["activity_time"] = "Aktivitätszeit",
    ["alert_active_description"] = "Aktivitätszeit seit letzer Kontrolle (Sekunden).",
    ["alert_bytes_description"] = "Layer 2 Bytes Delta (gesendet + erhalten)",
    ["alert_dns_description"] = "Layer 2 Bytes Delta (gesendet + erhalten) für DNS for DNS festgesteller Datenverkehr",
    ["alert_flows_description"] = "Flows Delta (als client + als server)",
    ["alert_idle_description"] = "Idle Zeit seit letztes Paket gesehen (Sekunden)",
    ["alert_network_egress_description"] = "Ausgangs Bytes Delta",
    ["alert_network_ingress_description"] = "Eingangs Bytes Delta",
    ["alert_network_inner_description"] = "Inneres Bytes Delta",
    ["alert_p2p_description"] = "Layer 2 Bytes Delta (gesendet + erhalten) für peer-to-peer festgestellter Datenverkehr",
    ["alert_packets_description"] = "Pakete Delta (gesendet + erhalten)",
    ["alert_throughput_description"] = "Durchschnitts throughput (gesendet + erhalten) [Mbps]",
    ["common_thresholds_local_sources"] = "Lokal %{source}s Common Thresholds",
    ["countries_contacts_description"] = "Alarm auslösen, wenn die Anzahl der kontaktierten Länder den Schwellenwert überschreitet",
    ["countries_contacts_title"] = "Länderkontakte Benachrichtigung",
    ["daily"] = "Täglich",
    ["dns_traffic"] = "DNS Datenverkehr",
    ["egress_traffic"] = "Ausgangsdatenverkehr",
    ["every_5_minutes"] = "Alle 5 Minuten",
    ["every_minute"] = "Jede Minute",
    ["hourly"] = "Stündlich",
    ["idle_time"] = "Idle Zeit",
    ["ingress_traffic"] = "Eingangsdatenverkehr",
    ["inner_traffic"] = "Innerer Datenverkehr",
    ["note_consecutive_checks"] = "Aufeinanderfolgende Kontrollen werden nicht notwendigerweise in aufeinanderfolgenden Perioden durchgeführt. Beispielsweise, wenn ein Host idle ist, werden seine thresholds nicht kontrolliert bis diese wieder aktiv werden.",
    ["note_control_threshold_checks_periods"] = "Thresholds welche in diesen tabs aufgelistet sind werden regelmässig überprüft. Verwenden Sie tabs um threshold Überprüfungszeiträume zu kontrollieren.",
    ["note_thresholds_expressed_as_delta"] = "Einige thresholds sind als Delta ausgedrückt. Ein Delta ist die Differenz der gleichen Menge zwischen zwei aufeinander folgeneden Kontrollen.",
    ["notes"] = "NOTIZEN",
    ["p2p_traffic"] = "P2P Datenverkehr",
    ["threshold_type"] = "Threshold Typ",
    ["thresholds_single_source"] = "%{source} %{alt_name} Thresholds",
    ["throughput"] = "Throughput",
  },
  ["arp_page"] = {
    ["arp_type"] = "ARP Typ",
  },
  ["as_details"] = {
    ["as"] = "Autonomes System",
    ["as_parameter_missing_message"] = "Autonomes Parametersystem fehlt (interner Fehler error?)",
    ["as_timeseries_enable_message"] = "AS timeseries können aktiviert werden von <A HREF=\"%{url}\">%{icon_flask} Preferences</A>. Wenige Minuten sind notwendig um die ersten Datenpunkte zu sehen.",
    ["no_available_data_for_as"] = "Data für AS ist nicht verfügbar %{asn}.",
  },
  ["as_stats"] = {
    ["autonomous_systems"] = "Autonome Systeme",
  },
  ["categories_page"] = {
    ["search_application"] = "Applikationssuche",
    ["target"] = "Ziel",
  },
  ["contacts_page"] = {
    ["client_address"] = "Client Adresse",
    ["client_contacts_initiator"] = "Client Kontakte (Initiator)",
    ["contacts"] = "Kontakte",
    ["no_client_contacts_so_far"] = "Bisher keine Client Kontakte",
    ["no_contacts_message"] = "Keine Kontakte für diesen Host",
    ["no_server_contacts_so_far"] = "Bisher keine Server Kontakte",
    ["server_address"] = "Server Adresse",
    ["server_contacts_receiver"] = "Server Kontakte (Receiver)",
  },
  ["dashboard"] = {
    ["actual_traffic"] = "Aktuelle Datenübertragungsraten",
    ["community_dashboard"] = "Community Übersicht",
    ["gateways_users"] = "Gateways und Benutzer",
    ["lastday_app_traffic"] = "Top Anwendungen und deren Datenübertragungsraten: letzte 24h",
    ["lastday_traffic"] = "Datenübertragungsraten Netzwerk Schnittstellen: letzte 24h",
    ["realtime_app_traffic"] = "Aktuelle Top Anwendungen und deren Datenübertragungsraten: aktuell",
    ["realtime_traffic"] = "Datenübertragungsraten Netzwerk Schnittstellen: aktuell",
    ["slow_dashboard_message"] = "Zu viel Latenz in der %{product} Antwort. Erwägen Sie die Einstellung einer höheren <a href='%{url}'>Aktualisierungsrate der Echtzeitstatistik</a>.",
    ["top_local_talkers"] = "Top Sender lokal",
    ["top_remote_destinations"] = "Top Ziele extern",
    ["traffic_dashboard"] = "Übersicht Netzwerkverkehr",
  },
  ["db_explorer"] = {
    ["abort"] = "Abbruch",
    ["all"] = "alle",
    ["app_between_talkers_pairs"] = "Applikationen zwischen pairs of talkers",
    ["app_flows_between"] = "%{app} Applikation Flows zwischen %{peer1} und %{peer2}",
    ["app_talkers"] = "%{app} talkers",
    ["app_talkers_with"] = "%{app} talkers mit %{peer}",
    ["application_flows"] = "Applikation Flows",
    ["applications_between"] = "Applikationen zwischen %{peer1} und %{peer2}",
    ["average_throughput"] = "Avg Thpt",
    ["client_server_breakdown"] = "Zusammenbruch des Datenverkehrs vom Client zum Server",
    ["client_server_host"] = "Client/Server Host",
    ["dns_query"] = "DNS Query",
    ["download_flows"] = "Download Flows",
    ["empty_query_response"] = "Leere Abfrageantwort (Datenbankabbruch oder Abfrage abgebrochen/Zeitlimit überschritten?)",
    ["extract_pcap"] = "Extract pcap",
    ["filter_bpf"] = "Filter (BPF)",
    ["first_last_seen"] = "Zuerst / zuletzt gesehen",
    ["flow_peers"] = "Flow Peers",
    ["get_proto_talkers"] = "Get Talkers beim Gebrauch dieses Protokolls",
    ["historical_data_explorer"] = "Historischer Datenexplorer",
    ["host_name"] = "Host Name",
    ["host_talkers"] = "%{host} talkers",
    ["hosts_talking_proto_with"] = "Hosts sprechen %{proto} mit {host}",
    ["http_host"] = "HTTP Host",
    ["http_method"] = "HTTP Method",
    ["interface_name"] = "Instance Name",
    ["last_hour_flows"] = "Gesehene Flows in der letzten Stunde",
    ["ms_client"] = "%{client} ms (client)",
    ["ms_server"] = "%{server} ms (server)",
    ["network_latency_breakdown"] = "Netzwerkzusammenbruch Latenz",
    ["observation_period"] = "Beobachtungsperiode",
    ["ok_request_sent"] = "OK, Anfrage gesendet",
    ["packet_rate"] = "Durchschnitts Paket Rate",
    ["pcap_requests_and_status"] = "Pcap Anfragen und Status",
    ["pcaps"] = "Pcaps",
    ["protocol_flows_between"] = "%{proto} Flowsprotokoll zwischen %{peer1} und %{peer2}",
    ["protocol_id"] = "Protokoll id",
    ["query_in_progress"] = "Database Anfrage im Gang, warten auf Resultate...",
    ["request_failed"] = "Anfrage gescheitert",
    ["response_code"] = "Response Code",
    ["search_flows"] = "Flows Suche",
    ["selected_saved"] = "Select saved",
    ["server_name"] = "Server Name",
    ["summary"] = "Überblick",
    ["talkers_with_this_host"] = "Talkers mit diesem Host",
    ["task_id"] = "Task Id",
    ["this_flow_has_been_reset"] = "Dieser Flow wurde zurückgesetzt und möglicherweise ist die Serverapplikation unten",
    ["this_flow_is_active"] = "Dieser Flow ist aktiv",
    ["this_flow_is_completed"] = "Dieser Flow ist vollendet und wird bald verfallen",
    ["top_flows_ipv4"] = "Top IPv4 Flows [%{date_from} - %{date_to}]",
    ["top_flows_ipv6"] = "Top IPv6 Flows [%{date_from} - %{date_to}]",
    ["top_proto_ipv4_flows"] = "Top %{proto} IPv4 Flows",
    ["top_proto_ipv6_flows"] = "Top %{proto} IPv6 Flows",
    ["total_flows"] = "Total Flows",
    ["total_packets"] = "Total Pakete",
    ["total_traffic"] = "Total Datenverkehr",
    ["traffic_rate"] = "Durchschnitts Verkehrsrate",
    ["traffic_received"] = "erhaltener Datenverkehr",
    ["traffic_sent"] = "gesendeter Datenverkehr",
    ["traffic_volume"] = "Verkehrsvolumen",
    ["unable_to_find_flow"] = "Unfähig den spezifizierten flow zu finden",
    ["unsave"] = "Entfernen",
    ["vlan_id"] = "VLAN Id",
  },
  ["details"] = {
    ["additional_mac_address"] = "Zusätzliche MAC Adresse",
    ["address_resolution_protocol"] = "Adressresolutions Protokoll",
    ["ago"] = "ago",
    ["alerts"] = "Warnungen",
    ["arp_replies"] = "ARP Antworten",
    ["arp_requests"] = "ARP Anfragen",
    ["as_client"] = "Als Client",
    ["as_server"] = "Als Server",
    ["device_port"] = "Device Port",
    ["device_type"] = "Geräte Typ",
    ["first_last_seen"] = "Zuerst / Zuletzt gesehen",
    ["flow_snmp_localization"] = "Flow SNMP Lokalisierung",
    ["flows_dropped_by_bridge"] = "Flows sind blockiert wegen Datenverkehrs Policies",
    ["flows_non_packet_iface"] = "Kürzlich Active Flows / Total",
    ["flows_packet_iface"] = "Active Flows / Total Active / Tiefes Goodput",
    ["further_host_names_information"] = "Weitere Host Namen/Information",
    ["goodput"] = "Goodput",
    ["host_pool"] = "Host Pool",
    ["host_snmp_localization"] = "Host SNMP Lokalisierung",
    ["input_device_port"] = "Device Input Port",
    ["label_blacklisted_host"] = "Host auf der schwarzen Liste",
    ["label_local_host"] = "Lokaler Host",
    ["label_private_ip"] = "Private IP",
    ["label_remote"] = "Remote",
    ["label_system_ip"] = "System IP",
    ["lost"] = "Verloren",
    ["note"] = "NOTIZ",
    ["note_hosts_located_snmp_device"] = "Hosts befinden sich in SNMP Geräten mit <A HREF=%{url}>Bridge MIB</A>.",
    ["out_of_order"] = "Ausser Betrieb",
    ["output_device_port"] = "Device Output Port",
    ["rcvd"] = "Rcvd",
    ["retransmissions"] = "Retransmissions",
    ["router_access_point_mac_address"] = "(Router/AccessPoint) MAC Adresse",
    ["sent_vs_received_traffic_breakdown"] = "Gesendet vs erhaltener Datenverkehr Breakdown",
    ["show_hosts"] = "Hosts zeigen",
    ["source_id"] = "Source Id",
    ["tcp_packets_sent_analysis"] = "TCP Pakete gesendet Analysis",
    ["total_traffic"] = "Gesamter Datenverkehr",
    ["traffic_sent_received"] = "Gesendeter / erhaltener Datenverkehr",
    ["vlan_id"] = "VLAN ID",
    ["whois_lookup"] = "Whois Lookup",
  },
  ["device_types"] = {
    ["iot"] = "IoT",
    ["laptop"] = "Laptop",
    ["multimedia"] = "Multimedia",
    ["nas"] = "NAS",
    ["networking"] = "Router/Switch",
    ["phone"] = "Telefon",
    ["printer"] = "Printer",
    ["tablet"] = "Tablet",
    ["tv"] = "TV",
    ["unknown"] = "Unbekannt",
    ["video"] = "Video",
    ["wifi"] = "Wireless Netzwerk",
    ["workstation"] = "Computer",
  },
  ["discover"] = {
    ["device"] = "Gerät",
    ["err_unable_to_arp_discovery"] = "Unfähig ARP Netzwerk Feststellung zu starten",
    ["error_no_discovery_cached"] = "Jetzt keine data Feststellung cached.",
    ["error_unable_to_decode_json"] = "Unfähig cache JSON Feststellung Data zu übersetzen.",
    ["ghost_icon_descr"] = "Die %{ghost_icon} icon markieren ghost hosts (d.h. die gehören nicht zu lang. Interface IP Adressennetzwerk)",
    ["network_discovery"] = "Netzwerk Feststellung",
    ["network_discovery_datetime"] = "Letzte Netzwerk Feststellung",
    ["network_discovery_not_enabled"] = "Eine Netzwerk Festellung ist im Gang. Diese Seite wird periodisch aktualisiert.",
  },
  ["dns_page"] = {
    ["dns_breakdown"] = "DNS Breakdown",
    ["dns_query_sent_distribution"] = "DNS Anfrage Sent Distribution",
    ["error_replies"] = "Fehler Antworten",
    ["note"] = "NOTIZ",
    ["note_dns_ratio"] = "Im Idealfall sollte das Anfrage vs Antwort DNS Verhältnis 1 sein (eine Antwort pro Anfrage). Wenn viel niedriger als das dann gibt es Probleme die es wert sind untersucht zu werden. Dies bedeutet, dass die Anzahl empfangener Antworten viel niedriger ist als erwartet, was darauf hindeutet, dass wir nicht reagierende DNS Resolver verwenden oder dass sie falsch konfiguriert sind (z.B. eine andere IP).",
    ["positive_replies"] = "Positive Replies",
    ["queries"] = "Anfragen",
    ["ratio"] = "Ratio",
    ["rcvd"] = "Rcvd",
    ["replies"] = "Antworten",
    ["reply_breakdown"] = "Antwort Breakdown",
    ["request_vs_reply"] = "Anfrage vs Antwort Ratio",
  },
  ["entity_thresholds"] = {
    ["flow_victim_description"] = "Maximale Anzahl der erhaltener Flows/Sek über die ein Host unter flood Angriff betrachtet wird",
    ["flow_victim_title"] = "Flow Flood Opfer",
    ["syn_victim_description"] = "Maximale Anzahl der erhaltener TCP SYN Pakete/Sek über die ein Host unter SYN flood Angriff betrachtet wird",
    ["syn_victim_title"] = "SYN Flood Opfer",
  },
  ["export_data"] = {
    ["export_json_data"] = "Export JSON Data",
    ["note_active_hosts"] = "Nur aktive Hosts werden zurückgegeben.",
    ["note_maximum_number"] = "Die maximale Anzahl der herunterladbaren Hosts ist 32,768.",
  },
  ["flow_alerts_explorer"] = {
    ["by_target_port"] = "Ziel Port",
    ["flow_alert_origin"] = "Ursprungsalarm",
    ["flow_alert_target"] = "Ziel Alarm",
    ["label"] = "Erforscher Flow Alarme",
    ["origins"] = "Ursprung",
    ["search"] = "Flow Alarmsuche",
    ["summary_cli2srv"] = "Total von Ursprung nach Ziel Datenverkehr",
    ["summary_n_origins"] = "Total Ursprung",
    ["summary_n_targets"] = "Total Ziele",
    ["summary_srv2cli"] = "Total von Ziel nach Ursprungsverkehr",
    ["summary_total"] = "Total Flow Alarme",
    ["targets"] = "Ziele",
    ["type_alerts_by_type"] = "Flow Alarme nach Typ",
    ["type_explorer"] = "Erforscher Typ",
    ["visual_explorer"] = "Visuelle Erforschung",
  },
  ["flow_details"] = {
    ["acceptable_label"] = "Akzeptabel",
    ["actual_peak_throughput"] = "Aktueller / Peak Throughput",
    ["additional_flow_elements"] = "Zusätzliche Flow Elemente",
    ["alert_type"] = "Flow Status",
    ["application_latency"] = "Applikationslatenz",
    ["average_cpu_load"] = "Average CPU Load",
    ["bittorrent_hash"] = "BitTorrent hash",
    ["blacklisted_flow"] = "Client oder Server auf der Blacklist(oder beide)",
    ["c_ip_addresses"] = "C IP Adressen",
    ["call_canceled"] = "Call gelöscht",
    ["call_completed"] = "Call abgeschlossen",
    ["call_error"] = "Call Fehler",
    ["call_id"] = "Call-ID",
    ["call_initiator"] = "Call Initiator",
    ["call_quality_indicators"] = "Call Qualitätsidentikator",
    ["call_started"] = "Call gestartet",
    ["call_state"] = "Call Status",
    ["called_party"] = "Called Party",
    ["cancel_bye_failure_reason_cause"] = "Cancel/Bye/Failure Reason Cause",
    ["certificates_not_match"] = "Zertifikate stimmen nicht überein",
    ["client_process_information"] = "Client Prozessinformation",
    ["client_requested"] = "Client angefordert",
    ["computed_as_tcp_window_size_rtt"] = "Wird als TCP Fenstergrösse berechnet / RTT",
    ["desirable_label"] = "Wünschenswert",
    ["dns_invalid_query"] = "Ungültige DNS Abfrage",
    ["dns_query"] = "DNS Query",
    ["drop_flow_traffic_btn"] = "Drop Flow Traffic",
    ["dropped_packets"] = "Fallen gelassene Pakete",
    ["dtmf_tones_sent"] = "Während des Gesprächs gesendete DTMF Töne",
    ["dump_flow_traffic"] = "Dump Flow Datenverkehr",
    ["first_last_flow_sequence"] = "Erste / Letzte Flow Sequenz",
    ["flow_active_msg"] = "Dieser Flow ist aktiv",
    ["flow_blocked_by_bridge"] = "Flüsse blockiert durch eine Konfigurationsregel",
    ["flow_cannot_be_found_message"] = "Dieser Flow ist unauffindbar.",
    ["flow_completed_msg"] = "Dieser Flow ist komplet und wird bald verfallen",
    ["flow_emitted"] = "Flow wurde ausgegeben wenn die Netzwerk interface alarmiert wurde",
    ["flow_peer_roles_inaccurate_msg"] = "Flow Start wurde jedoch noch nicht angezeigt peer roles (Client/Server) können ungenau sein",
    ["flow_peers_client_server"] = "Flow Peers [ Client / Server ]",
    ["flow_quota"] = "Flow Quota",
    ["flow_reset_by_resetter_msg"] = "Dieser Flow wurde zurückgesetzt durch %{resetter}",
    ["flow_reset_msg"] = "Dieser Flow wurde zurückgesetzt",
    ["flow_shapers"] = "Flow Shapers",
    ["forward"] = "Forward",
    ["gsm_cell_identifier"] = "GSM Cell Identifikator",
    ["gsm_cell_lac"] = "GSM Cell LAC (Location Area Code)",
    ["http_method"] = "HTTP Methode",
    ["icmp_info"] = "ICMP Info",
    ["imsi"] = "IMSI (International mobile Subscriber Identity)",
    ["io_wait_time_percentage"] = "I/O Wartezeit in Prozent",
    ["jitter"] = "Jitter",
    ["looks_like_idle_flow_message"] = "Dies sieht aus wie ein <font color=red>idle flow</font> mit periodischen Übertragungen nur um es lebend zu erhalten.",
    ["lost_packets"] = "Verlorene Pakete",
    ["low_goodput"] = "Low Goodput",
    ["max_estimated_tcp_throughput"] = "Maximale (Geschätzt) TCP Throughput",
    ["max_packet_interarrival_time"] = "Max Packet Interarrival Time",
    ["memory_actual_peak"] = "Memory Aktueller / Peak",
    ["normal"] = "Normal",
    ["not_recommended_label"] = "Nicht empfehlenswert",
    ["nsapi"] = "NSAPI",
    ["ongoing_call"] = "Laufender Call",
    ["packet_inter_arrival_time"] = "Paket interne Ankunftszeit <br>[ Min / Avg / Max ]",
    ["payload_type"] = "Payload Type",
    ["process_information_report_warning"] = "Der Prozessinformationsbericht ist begrenzt es sei denn Sie verwenden ntopng mit <A HREF='%{url}'>nProbe</A> und der sprobe plugin",
    ["process_pid_name"] = "Prozess PID/Name",
    ["profile_name"] = "Profilname",
    ["pseudo_mos"] = "(Pseudo) MOS",
    ["r_factor"] = "R-Factor",
    ["reach_connection_label"] = "Verbindung erreichen",
    ["remote_to_remote"] = "Remote Client und remote Server",
    ["response_code"] = "Response Code",
    ["reverse"] = "Reverse",
    ["round_trip_time"] = "Round Trip Time",
    ["rtp_codecs"] = "RTP Codecs",
    ["rtp_flow"] = "RTP Flow",
    ["rtp_protocol_information"] = "RTP Protokollinformation",
    ["rtp_stream_peers"] = "RTP Stream Peers",
    ["rtp_transit_in_out"] = "RTP Transit IN / OUT",
    ["rtt_breakdown"] = "Netzwerk Round-Trip Trip Breakdown",
    ["sac_service_area_code"] = "SAC (Service Area Code)",
    ["server_name"] = "Server Name",
    ["server_process_information"] = "Server Prozessinformation",
    ["sip_call_id"] = "SIP Call-ID",
    ["sip_protocol_information"] = "SIP Protokollinformation",
    ["slow_application_header"] = "Slow Application Header",
    ["slow_data_exchange"] = "Slow Data Exchange",
    ["slow_tcp_connection"] = "Slow TCP Verbingung",
    ["son_of_father_process"] = "son of <a href ='%{url}'>%{proc_father_pid}/%{proc_father_name}</a>",
    ["ssh_signature"] = "SSH Unterschrift",
    ["suspicious_tcp_probing"] = "Suspicious TCP Probing",
    ["suspicious_tcp_syn_probing"] = "Suspicious TCP SYN probing",
    ["sync_source_id"] = "Sync Source ID",
    ["tcp_connection_issues"] = "TCP Connection Issues (Retransmission, OOO, Lost)",
    ["tcp_packet_analysis"] = "TCP Paketanalyse",
    ["throughput_trend"] = "Throughput Trend",
    ["tls_certificate"] = "TLS Zertifikat",
    ["tls_certificate_mismatch"] = "TLS Certificate Mismatch",
    ["unknown_status"] = "Unbekannter Status (%{status})",
    ["url"] = "URL",
    ["user_name"] = "User Name",
    ["vm_page_faults"] = "VM Page Faults",
  },
  ["flow_fields_description"] = {
    ["appl_latency_ms"] = "Application latency (msec), a.k.a. server response time",
    ["application_id"] = "Gesammelte Application Id (Cisco or IXIA)",
    ["application_name"] = "Palo Alto App-Id",
    ["biflow_direction"] = "1=initiator, 2=reverseInitiator",
    ["bittorrent_hash"] = "BITTORRENT hash",
    ["client_nw_latency_ms"] = "Netzwerk RTT/2 client <-> nprobe (msec)",
    ["cumulative_icmp_type"] = "Kumulative OR der ICMP Paketetypen",
    ["dhcp_client_ip"] = "DHCP zugewiesene client IPv4 Adresse",
    ["dhcp_client_mac"] = "MAC of the DHCP client",
    ["dhcp_client_name"] = "DHCP client Name",
    ["dhcp_message_type"] = "DHCP Nachrichtentyp",
    ["dhcp_remote_id"] = "DHCP agent remote Id",
    ["dhcp_subscriber_id"] = "DHCP gezeichnete Id",
    ["diameter_clr_cancel_type"] = "DIAMETER Löschungstyp",
    ["diameter_clr_flags"] = "DIAMETER CLR Flags",
    ["diameter_exp_res_result_code"] = "DIAMETER Antwort Experimentergebnis Code",
    ["diameter_exp_res_vendor_id"] = "DIAMETER Antwort Experimentergebnis Vendor Id",
    ["diameter_hop_by_hop_id"] = "DIAMETER Hop by Hop Erkenner",
    ["diameter_req_msg_type"] = "DIAMETER Anfrage Msg Type",
    ["diameter_req_origin_host"] = "DIAMETER Origin Host Anfrage",
    ["diameter_req_user_name"] = "DIAMETER Benutzername anfordern",
    ["diameter_rsp_msg_type"] = "DIAMETER Antwort Msg Type",
    ["diameter_rsp_origin_host"] = "DIAMETER Origin Host Antwort",
    ["diameter_rsp_result_code"] = "DIAMETER Antwort Ergebnis Code",
    ["direction"] = "Flow Direktion [0=src->dst, 1=dst->src]",
    ["dns_num_answers"] = "DNS # der zurückgegebenen Antworten",
    ["dns_query"] = "DNS Abfrage",
    ["dns_query_id"] = "DNS Abfragetransaktions Id",
    ["dns_query_type"] = "DNS Abfragetyp (e.g. 1=A, 2=NS..)",
    ["dns_response"] = "DNS Antwort(s)",
    ["dns_ret_code"] = "DNS return code (e.g. 0=no error)",
    ["dns_ttl_answer"] = "TTL des ersten A record (if any)",
    ["dot1q_dst_vlan"] = "Destination VLAN (outer VLAN in QinQ)",
    ["dot1q_src_vlan"] = "Source VLAN (outer VLAN in QinQ)",
    ["downstream_session_id"] = "Downstream Session Kennzeichner (e.g. L2TP) oder 0 wenn unbekannt",
    ["downstream_tunnel_id"] = "Downstream Tunnelkennzeichner (e.g. GTP TEID, VXLAN VNI) oder 0 wenn unbekannt",
    ["dst_as"] = "Destination BGP AS",
    ["dst_as_map"] = "Organisationsname für DST_AS",
    ["dst_as_path_1"] = "Dest AS path Position 1",
    ["dst_as_path_10"] = "Dest AS path Position 10",
    ["dst_as_path_2"] = "Dest AS path Position 2",
    ["dst_as_path_3"] = "Dest AS path Position 3",
    ["dst_as_path_4"] = "Dest AS path Position 4",
    ["dst_as_path_5"] = "Dest AS path Position 5",
    ["dst_as_path_6"] = "Dest AS path Position 6",
    ["dst_as_path_7"] = "Dest AS path Position 7",
    ["dst_as_path_8"] = "Dest AS path Position 8",
    ["dst_as_path_9"] = "Dest AS path Position 9",
    ["dst_father_proc_name"] = "Dst father process name",
    ["dst_father_proc_pid"] = "Dst father process PID",
    ["dst_fragments"] = "Num fragmentierter Pakete dst->src",
    ["dst_ip_city"] = "Stadt in der sich die dst IP befindet",
    ["dst_ip_country"] = "Land in dem sich die dst IP befindet",
    ["dst_ip_lat"] = "Breitengrad in dem sich die dst IP befindet",
    ["dst_ip_long"] = "Längengrad in dem sich die dst IP befindet",
    ["dst_proc_actual_memory"] = "Dst process actual memory (bytes)",
    ["dst_proc_average_cpu_load"] = "Dst process avg load (%% * 100)",
    ["dst_proc_name"] = "Dst process name",
    ["dst_proc_num_page_faults"] = "Dst process num pagefaults",
    ["dst_proc_pctg_iowait"] = "Src process iowait time %% (%% * 100)",
    ["dst_proc_peak_memory"] = "Dst process peak memory (bytes)",
    ["dst_proc_pid"] = "Dst process PID",
    ["dst_proc_uid"] = "Dst process UID",
    ["dst_proc_user_name"] = "Dst process user name",
    ["dst_to_src_avg_throughput"] = "Dst to src average thpt (bps)",
    ["dst_to_src_max_throughput"] = "Dst to src max thpt (bps)",
    ["dst_to_src_min_throughput"] = "Dst to src min thpt (bps)",
    ["dst_tos"] = "TOS/DSCP (dst->src)",
    ["dst_vlan"] = "Destination VLAN (inner VLAN in QinQ)",
    ["duration_in"] = "Streamingdauer vom Client zum Server (msec)",
    ["duration_out"] = "Streamingdauer vom Client zum Server (msec)",
    ["engine_id"] = "Id der flow switching engine",
    ["engine_type"] = "Flow switching engine",
    ["exporter_ipv4_address"] = "Exporter IPv4 Adresse",
    ["exporter_ipv6_address"] = "Exporter IPv6 Adresse",
    ["firewall_event"] = "Firewall Event 0=ignorieren, 1=Flow kreirt, 2=Flow gelöscht, 3=Flow verweigert, 4=Flow Warnung, 5=flow update",
    ["first_switched"] = "SysUptime (msec) des ersten Flow pkt",
    ["flow_active_timeout"] = "Aktivitäts Timeout von Flow Cache Einträgen",
    ["flow_duration_microseconds"] = "Flow Dauer (usec)",
    ["flow_duration_milliseconds"] = "Flow Dauer (msec)",
    ["flow_end_microseconds"] = "uSec (epoch) des ersten Flow Pakets",
    ["flow_end_milliseconds"] = "Msec (epoch) des letzten Flow Pakets",
    ["flow_end_sec"] = "Sekunden (epoch) des letzten Flow Pakets",
    ["flow_id"] = "Serial Flow Identifikator",
    ["flow_inactive_timeout"] = "Inaktivitäts Timeout von Flow Cache Einträgen",
    ["flow_proto_port"] = "L7 port welcher das Flowprotokoll oder 0 wenn unbekannt identifiziert",
    ["flow_server_name"] = "Flow Servername (if known)",
    ["flow_start_microseconds"] = "uSec (epoch) des ersten Flow Pakets",
    ["flow_start_milliseconds"] = "Msec (epoch) des ersten Flow Pakets",
    ["flow_start_sec"] = "Sekunden (epoch) des ersten Flow Pakets",
    ["flow_user_name"] = "Flow Nutzername des tunnel (if known)",
    ["frame_length"] = "Originale L2 frame Länge",
    ["ftp_command"] = "FTP client command",
    ["ftp_command_ret_code"] = "FTP client command return code",
    ["ftp_login"] = "FTP client login",
    ["ftp_password"] = "FTP client Kennwort",
    ["gtpv0_apn_name"] = "GTPv0 APN Name",
    ["gtpv0_end_user_ip"] = "GTPv0 Endbenutzer IP Adresse",
    ["gtpv0_end_user_msisdn"] = "GTPv0 Endbenutzer MSISDN",
    ["gtpv0_rai_cell_lac"] = "GTPv0 Cell Location Area Code",
    ["gtpv0_rai_cell_rac"] = "GTPv0 Cell Routing Area Code",
    ["gtpv0_rai_mcc"] = "GTPv0 Mobiler Ländercode",
    ["gtpv0_rai_mnc"] = "GTPv0 Mobiler Netzwerkcode",
    ["gtpv0_req_msg_type"] = "GTPv0 Anfrage Msg Typ",
    ["gtpv0_response_cause"] = "GTPv0 Cause of Operation",
    ["gtpv0_rsp_msg_type"] = "GTPv0 Antwort Msg Typ",
    ["gtpv0_tid"] = "GTPv0 Tunnel Erkenner",
    ["gtpv1_apn_name"] = "GTPv1 APN Name",
    ["gtpv1_c2s_teid_ctrl"] = "GTPv1 Client->Server TunnelId Control",
    ["gtpv1_c2s_teid_data"] = "GTPv1 Client->Server TunnelId Data",
    ["gtpv1_end_user_imei"] = "GTPv1 End User IMEI",
    ["gtpv1_end_user_imsi"] = "GTPv1 End User IMSI",
    ["gtpv1_end_user_ip"] = "GTPv1 End User IP Address",
    ["gtpv1_end_user_msisdn"] = "GTPv1 End User MSISDN",
    ["gtpv1_rai_lac"] = "GTPv1 RAI Location Area Code",
    ["gtpv1_rai_mcc"] = "GTPv1 RAI Mobile Country Code",
    ["gtpv1_rai_mnc"] = "GTPv1 RAI Mobile Network Code",
    ["gtpv1_rai_rac"] = "GTPv1 RAI Routing Area Code",
    ["gtpv1_rat_type"] = "GTPv1 RAT Type",
    ["gtpv1_req_msg_type"] = "GTPv1 Request Msg Type",
    ["gtpv1_response_cause"] = "GTPv1 Cause of Operation",
    ["gtpv1_rsp_msg_type"] = "GTPv1 Response Msg Type",
    ["gtpv1_s2c_teid_ctrl"] = "GTPv1 Server->Client TunnelId Control",
    ["gtpv1_s2c_teid_data"] = "GTPv1 Server->Client TunnelId Data",
    ["gtpv1_uli_cell_ci"] = "GTPv1 ULI Cell CI",
    ["gtpv1_uli_cell_lac"] = "GTPv1 ULI Cell Location Area Code",
    ["gtpv1_uli_mcc"] = "GTPv1 ULI Mobile Country Code",
    ["gtpv1_uli_mnc"] = "GTPv1 ULI Mobile Network Code",
    ["gtpv1_uli_sac"] = "GTPv1 ULI SAC",
    ["gtpv2_apn_name"] = "GTPv2 APN Name",
    ["gtpv2_c2s_s1u_gtpu_ip"] = "GTPv2 Client->Svr S1U GTPU IP",
    ["gtpv2_c2s_s1u_gtpu_teid"] = "GTPv2 Client->Svr S1U GTPU TEID",
    ["gtpv2_c2s_s5_s8_gtpc_ip"] = "GTPv2 Client->Svr S5/S8 GTPC IP",
    ["gtpv2_c2s_s5_s8_gtpu_ip"] = "GTPv2 Client->Srv S5/S8 PGW GTPU IP",
    ["gtpv2_c2s_s5_s8_gtpu_teid"] = "GTPv2 Client->Srv S5/S8 PGW GTPU TEID",
    ["gtpv2_c2s_s5_s8_sgw_gtpu_ip"] = "GTPv2 Client->Srv S5/S8 SGW GTPU IP",
    ["gtpv2_c2s_s5_s8_sgw_gtpu_teid"] = "GTPv2 Client->Srv S5/S8 SGW GTPU TEID",
    ["gtpv2_end_user_imei"] = "GTPv2 End User IMEI",
    ["gtpv2_end_user_imsi"] = "GTPv2 End User IMSI",
    ["gtpv2_end_user_msisdn"] = "GTPv2 End User MSISDN",
    ["gtpv2_pdn_ip"] = "GTPV2 PDN IP Address",
    ["gtpv2_rat_type"] = "GTPv2 RAT Type",
    ["gtpv2_req_msg_type"] = "GTPv2 Request Msg Type",
    ["gtpv2_response_cause"] = "GTPv2 Cause of Operation",
    ["gtpv2_rsp_msg_type"] = "GTPv2 Response Msg Type",
    ["gtpv2_s2c_s1u_gtpu_ip"] = "GTPv2 Srv->Client S1U GTPU IP",
    ["gtpv2_s2c_s1u_gtpu_teid"] = "GTPv2 Srv->Client S1U GTPU TEID",
    ["gtpv2_s2c_s5_s8_gtpc_ip"] = "GTPv2 Svr->Client S5/S8 GTPC IP",
    ["gtpv2_s2c_s5_s8_gtpu_ip"] = "GTPv2 Srv->Client S5/S8 PGW GTPU IP",
    ["gtpv2_s2c_s5_s8_gtpu_teid"] = "GTPv2 Srv->Client S5/S8 PGW GTPU TEID",
    ["gtpv2_s2c_s5_s8_sgw_gtpu_ip"] = "GTPv2 Srv->Client S5/S8 SGW GTPU IP",
    ["gtpv2_s2c_s5_s8_sgw_gtpu_teid"] = "GTPv2 Srv->Client S5/S8 SGW GTPU TEID",
    ["gtpv2_s5_s8_gtpc_teid"] = "GTPv2 S5/S8 SGW GTPC TEIDs",
    ["gtpv2_uli_cell_id"] = "GTPv2 Cell Identifier",
    ["gtpv2_uli_cell_tac"] = "GTPv2 Tracking Area Code",
    ["gtpv2_uli_mcc"] = "GTPv2 Mobile Country Code",
    ["gtpv2_uli_mnc"] = "GTPv2 Mobile Network Code",
    ["http_host"] = "HTTP Host Name (IXIA Host Name)",
    ["http_method"] = "HTTP METHOD",
    ["http_mime"] = "HTTP Mime Type",
    ["http_referer"] = "HTTP Referer",
    ["http_ret_code"] = "HTTP return code (e.g. 200, 304...)",
    ["http_site"] = "HTTP server without host name",
    ["http_ua"] = "HTTP User Agent",
    ["http_url"] = "HTTP URL (IXIA URI)",
    ["http_via"] = "HTTP Via",
    ["http_x_forwarded_for"] = "HTTP X-Forwarded-For",
    ["icmp_ipv4_code"] = "ICMP Code",
    ["icmp_ipv4_type"] = "ICMP Typ",
    ["icmp_type"] = "ICMP Type * 256 + ICMP code",
    ["imap_login"] = "Mail sender",
    ["in_bytes"] = "Eingehende Flow Bytes (src->dst)",
    ["in_dst_mac"] = "Destinations MAC Adresse",
    ["in_pkts"] = "Eingehende Flow Pakete (src->dst)",
    ["in_src_mac"] = "Source MAC Adresse",
    ["in_src_osi_sap"] = "OSI Source SAP (OSI Traffic Only)",
    ["ingress_vrfid"] = "Eingang VRF ID",
    ["input_snmp"] = "Input interface SNMP idx",
    ["ip_protocol_version"] = "[4=IPv4][6=IPv6]",
    ["ipfix_sampling_algorithm"] = "Sampling algorithm",
    ["ipv4_dst_addr"] = "IPv4 Destinationsadresse",
    ["ipv4_dst_mask"] = "IPv4 dest subnet mask (/<bits>)",
    ["ipv4_next_hop"] = "IPv4 nächste hop Adresse",
    ["ipv4_src_addr"] = "IPv4 source Adresse",
    ["ipv4_src_mask"] = "IPv4 source subnet mask (/<bits>)",
    ["ipv6_dst_addr"] = "IPv6 Destinationadresse",
    ["ipv6_dst_mask"] = "IPv6 Destinations mask",
    ["ipv6_next_hop"] = "IPv6 nächste hop address",
    ["ipv6_src_addr"] = "IPv6 source Adresse",
    ["ipv6_src_mask"] = "IPv6 source mask",
    ["l4_dst_port"] = "IPv4 Destinations port",
    ["l4_dst_port_map"] = "Layer 4 Destinations port symbolischer Name",
    ["l4_src_port"] = "IPv4 source port",
    ["l4_src_port_map"] = "Layer 4 source port symbolischer Name",
    ["l4_srv_port"] = "Layer 4 Server port",
    ["l4_srv_port_map"] = "Layer 4 Server port symbolischer Name",
    ["l7_proto"] = "Layer 7 Protokoll (numeric)",
    ["l7_proto_name"] = "Layer 7 Protokollname",
    ["last_switched"] = "SysUptime (msec) des letzten Flow pkt",
    ["longest_flow_pkt"] = "Längstes Paket (bytes) des Flows",
    ["max_ttl"] = "Max flow TTL",
    ["min_ttl"] = "Min flow TTL",
    ["mpls_label_1"] = "MPLS label auf Position 1",
    ["mpls_label_10"] = "MPLS label auf Position 10",
    ["mpls_label_2"] = "MPLS label auf Position 2",
    ["mpls_label_3"] = "MPLS label auf Position 3",
    ["mpls_label_4"] = "MPLS label auf Position 4",
    ["mpls_label_5"] = "MPLS label auf Position 5",
    ["mpls_label_6"] = "MPLS label auf Position 6",
    ["mpls_label_7"] = "MPLS label auf Position 7",
    ["mpls_label_8"] = "MPLS label auf Position 8",
    ["mpls_label_9"] = "MPLS label auf Position 9",
    ["mysql_appl_latency_usec"] = "MySQL request->response latecy (usec)",
    ["mysql_db"] = "MySQL database in use",
    ["mysql_query"] = "MySQL Query",
    ["mysql_response"] = "MySQL server response",
    ["mysql_server_version"] = "MySQL server version",
    ["mysql_username"] = "MySQL username",
    ["netbios_query_name"] = "NETBIOS Query Name",
    ["netbios_query_os"] = "NETBIOS Query OS",
    ["netbios_query_type"] = "NETBIOS Query Type",
    ["netbios_response"] = "NETBIOS Query Response",
    ["nprobe_ipv4_address"] = "IPv4 Adress des Hosts bei welche nProbe läuft",
    ["num_pkts_1024_to_1514_bytes"] = "# Pakete mit IP Grösse > 1024 und <= 1514",
    ["num_pkts_128_to_256_bytes"] = "# Pakete mit IP Grösse > 128 und <= 256",
    ["num_pkts_256_to_512_bytes"] = "# Pakete mit IP Grösse > 256 und < 512",
    ["num_pkts_512_to_1024_bytes"] = "# Pakete mit IP Gösse > 512 und < 1024",
    ["num_pkts_over_1514_bytes"] = "# Pakete mit Grösse > 1514",
    ["num_pkts_ttl_128_160"] = "# Pakete mit TTL > 128 und <= 160",
    ["num_pkts_ttl_160_192"] = "# Pakete mit TTL > 160 und <= 192",
    ["num_pkts_ttl_192_224"] = "# Pakete mit TTL > 192 und <= 224",
    ["num_pkts_ttl_224_255"] = "# Pakete mit TTL > 224 und <= 255",
    ["num_pkts_ttl_2_5"] = "# Pakete mit TTL > 1 und TTL <= 5",
    ["num_pkts_ttl_32_64"] = "# Pakete mit TTL > 32 und <= 64",
    ["num_pkts_ttl_5_32"] = "# Pakete mit TTL > 5 und TTL <= 32",
    ["num_pkts_ttl_64_96"] = "# Pakete mit TTL > 64 und <= 96",
    ["num_pkts_ttl_96_128"] = "# Pakete mit TTL > 96 und <= 128",
    ["num_pkts_ttl_eq_1"] = "# Pakete mit TTL = 1",
    ["num_pkts_up_to_128_bytes"] = "# Pakete mit IP Grösse <= 128",
    ["observation_point_id"] = "Beobachtungspunkt id",
    ["observation_point_type"] = "Beobachtungspunkt Typ",
    ["ooorder_in_pkts"] = "Anzahl der TCP Flow Pakete ausser Betrieb (dst->src)",
    ["ooorder_out_pkts"] = "Anzahl der TCP Flow Pakete ausser Betrieb (src->dst)",
    ["oracle_query"] = "Oracle Query",
    ["oracle_query_duration"] = "Oracle Query Duration (msec)",
    ["oracle_rsp_code"] = "Oracle Response Code",
    ["oracle_rsp_string"] = "Oracle Response String",
    ["oracle_username"] = "Oracle Username",
    ["out_bytes"] = "Ausgehende Flow Bytes (dst->src) [Aliased to %%DST_TO_SRC_BYTES]",
    ["out_dst_mac"] = "Destinations MAC Adresse, möglicherweise modifiziert durch eine middlebox Funktion nach dem Beobachtungspunkt",
    ["out_dst_osi_sap"] = "OSI Destinations SAP (OSI Traffic Only)",
    ["out_pkts"] = "Ausgehende Flow Pakete (dst->src) [Aliased to %%DST_TO_SRC_PKTS]",
    ["out_src_mac"] = "Source MAC Adresse, potentially modified by a middlebox function after the Observation Point",
    ["output_snmp"] = "Output interface SNMP idx",
    ["packet_section_offset"] = "Paketsektion offset",
    ["packets_observed"] = "Tot Anzahl der gesehenen Pakete",
    ["packets_selected"] = "Anzahl der ausgewählten pkts für sampling",
    ["payload_hash"] = "Anfangsflow payload hash",
    ["plugin_name"] = "Benutzter Plugin Name von diesem (if any)",
    ["pop_user"] = "POP3 user login",
    ["post_napt_dst_transport_port"] = "Post NAPT Destination Transport Port",
    ["post_napt_src_transport_port"] = "Post NAPT Source Transport Port",
    ["post_nat_dst_ipv4_addr"] = "Post NAT Destination IPv4 Adresse",
    ["post_nat_src_ipv4_addr"] = "Post NAT Source IPv4 Adresse",
    ["protocol"] = "IP Protokoll Byte",
    ["protocol_map"] = "IP Protokollname",
    ["radius_acct_in_octets"] = "RADIUS Accounting Input Octets",
    ["radius_acct_in_pkts"] = "RADIUS Accounting Input Packets",
    ["radius_acct_out_octets"] = "RADIUS Accounting Output Octets",
    ["radius_acct_out_pkts"] = "RADIUS Accounting Output Packets",
    ["radius_acct_session_id"] = "RADIUS Accounting Session Name",
    ["radius_acct_status_type"] = "RADIUS Accounting Status Type",
    ["radius_called_station_id"] = "RADIUS Called Station Id",
    ["radius_calling_station_id"] = "RADIUS Calling Station Id",
    ["radius_framed_ip_addr"] = "RADIUS Framed IP",
    ["radius_nas_identifier"] = "RADIUS NAS Identifier",
    ["radius_nas_ip_addr"] = "RADIUS NAS IP Address",
    ["radius_req_msg_type"] = "RADIUS Request Msg Type",
    ["radius_rsp_msg_type"] = "RADIUS Response Msg Type",
    ["radius_user_imei"] = "RADIUS User MSISDN (Extension)",
    ["radius_user_imsi"] = "RADIUS User IMSI (Extension)",
    ["radius_user_name"] = "RADIUS User Name (Access Only)",
    ["retransmitted_in_bytes"] = "Anzahl der erneut übertragenen TCP Flow Bytes (src->dst)",
    ["retransmitted_in_pkts"] = "Anzahl der erneut übertragenen TCP Flow Pakete (src->dst)",
    ["retransmitted_out_bytes"] = "Anzahl der erneut übertragenen TCP Flow Bytes (dst->src)",
    ["retransmitted_out_pkts"] = "Anzahl der erneut übertragenen TCP Flow Pakete (dst->src)",
    ["rtp_dtmf_tones"] = "DTMF tones sent (if any) during the call",
    ["rtp_first_seq"] = "First flow RTP Seq Number",
    ["rtp_first_ts"] = "First flow RTP timestamp",
    ["rtp_in_jitter"] = "RTP jitter (ms * 1000)",
    ["rtp_in_max_delta"] = "Max delta (ms*100) between consecutive pkts (src->dst)",
    ["rtp_in_mos"] = "RTP pseudo-MOS (value * 100) (src->dst)",
    ["rtp_in_payload_type"] = "RTP payload type",
    ["rtp_in_pkt_drop"] = "Packet discarded by Jitter Buffer (src->dst)",
    ["rtp_in_pkt_lost"] = "Packet lost in stream (src->dst)",
    ["rtp_in_r_factor"] = "RTP pseudo-R_FACTOR (value * 100) (src->dst)",
    ["rtp_in_transit"] = "RTP Transit (value * 100) (src->dst)",
    ["rtp_last_seq"] = "Last flow RTP Seq Number",
    ["rtp_last_ts"] = "Last flow RTP timestamp",
    ["rtp_mos"] = "RTP pseudo-MOS (value * 100) (average both directions)",
    ["rtp_out_jitter"] = "RTP jitter (ms * 1000)",
    ["rtp_out_max_delta"] = "Max delta (ms*100) between consecutive pkts (dst->src)",
    ["rtp_out_mos"] = "RTP pseudo-MOS (value * 100) (dst->src)",
    ["rtp_out_payload_type"] = "RTP payload type",
    ["rtp_out_pkt_drop"] = "Packet discarded by Jitter Buffer (dst->src)",
    ["rtp_out_pkt_lost"] = "Packet lost in stream (dst->src)",
    ["rtp_out_r_factor"] = "RTP pseudo-R_FACTOR (value * 100) (dst->src)",
    ["rtp_out_transit"] = "RTP Transit (value * 100) (dst->src)",
    ["rtp_r_factor"] = "RTP pseudo-R_FACTOR (value * 100) (average both directions)",
    ["rtp_rtt"] = "RTP Round Trip Time (ms)",
    ["rtp_sip_call_id"] = "SIP call-id corresponding to this RTP stream",
    ["rtp_ssrc"] = "RTP Sync Source ID",
    ["s1ap_cause_enb_to_mme"] = "S1AP Cause from ENB to MME",
    ["s1ap_detailed_cause_enb_to_mme"] = "S1AP Detailed Cause from ENB to MME",
    ["s1ap_enb_ue_s1ap_id"] = "S1AP ENB Identifier",
    ["s1ap_mme_ue_s1ap_id"] = "S1AP MME Identifier",
    ["s1ap_msg_emm_type_enb_to_mme"] = "S1AP EMM Message Type from ENB to MME",
    ["s1ap_msg_emm_type_mme_to_enb"] = "S1AP EMM Message Type from MME to ENB",
    ["s1ap_msg_esm_type_enb_to_mme"] = "S1AP ESM Message Type from ENB to MME",
    ["s1ap_msg_esm_type_mme_to_enb"] = "S1AP ESM Message Type from MME to ENB",
    ["sampled_packet_id"] = "Sampled Paket id",
    ["sampled_packet_size"] = "Sampled Paketgrösse",
    ["sampling_algorithm"] = "Sampling type (deterministic/random)",
    ["sampling_interval"] = "Sampling rate",
    ["sampling_population"] = "Sampling Bevölkerung",
    ["sampling_size"] = "Anzahl der zu testenden Pakete",
    ["selector_id"] = "Selector id",
    ["selector_name"] = "Sampler Name",
    ["server_nw_latency_ms"] = "Netzwerk RTT/2 nprobe <-> server (msec)",
    ["shortest_flow_pkt"] = "Kürzestes Paket (bytes) des Flows",
    ["sip_bye_ok_time"] = "SIP time (epoch) of BYE OK",
    ["sip_bye_time"] = "SIP time (epoch) of BYE",
    ["sip_c_ip"] = "SIP C IP adresses",
    ["sip_call_id"] = "SIP call-id",
    ["sip_call_state"] = "SIP Call State",
    ["sip_called_party"] = "SIP Called party",
    ["sip_calling_party"] = "SIP Call initiator",
    ["sip_cancel_ok_time"] = "SIP time (epoch) of CANCEL OK",
    ["sip_cancel_time"] = "SIP time (epoch) of CANCEL",
    ["sip_invite_failure_time"] = "SIP time (epoch) of INVITE FAILURE",
    ["sip_invite_ok_time"] = "SIP time (epoch) of INVITE OK",
    ["sip_invite_time"] = "SIP time (epoch) of INVITE",
    ["sip_reason_cause"] = "SIP Cancel/Bye/Failure reason cause",
    ["sip_response_code"] = "SIP failure response code",
    ["sip_ringing_time"] = "SIP time (epoch) of RINGING",
    ["sip_rtp_codecs"] = "SIP RTP codecs",
    ["sip_rtp_ipv4_dst_addr"] = "SIP RTP stream dest IP",
    ["sip_rtp_ipv4_src_addr"] = "SIP RTP stream source IP",
    ["sip_rtp_l4_dst_port"] = "SIP RTP stream dest port",
    ["sip_rtp_l4_src_port"] = "SIP RTP stream source port",
    ["sip_trying_time"] = "SIP time (epoch) of Trying",
    ["smtp_mail_from"] = "Mail sender",
    ["smtp_rcpt_to"] = "Mail recipient",
    ["src_as"] = "Source BGP AS",
    ["src_as_map"] = "Organisationsname für SRC_AS",
    ["src_as_path_1"] = "Src AS path Position 1",
    ["src_as_path_10"] = "Src AS path Position 10",
    ["src_as_path_2"] = "Src AS path Position 2",
    ["src_as_path_3"] = "Src AS path Position 3",
    ["src_as_path_4"] = "Src AS path Position 4",
    ["src_as_path_5"] = "Src AS path Position 5",
    ["src_as_path_6"] = "Src AS path Position 6",
    ["src_as_path_7"] = "Src AS path Position 7",
    ["src_as_path_8"] = "Src AS path Position 8",
    ["src_as_path_9"] = "Src AS path Position 9",
    ["src_father_proc_name"] = "Src father process name",
    ["src_father_proc_pid"] = "Src father process PID",
    ["src_fragments"] = "Num fragmentierter Pakete src->dst",
    ["src_ip_city"] = "Stadt in der sich die src IP befindet",
    ["src_ip_country"] = "Land in dem sich die src IP befindet",
    ["src_ip_lat"] = "Breitengrad in dem sich die src IP befindet",
    ["src_ip_long"] = "Längengrad in dem sich die src IP befindet",
    ["src_proc_actual_memory"] = "Src process actual memory (bytes)",
    ["src_proc_average_cpu_load"] = "Src process avg load (%% * 100)",
    ["src_proc_name"] = "Src process name",
    ["src_proc_num_page_faults"] = "Src process num pagefaults",
    ["src_proc_pctg_iowait"] = "Src process iowait time %% (%% * 100)",
    ["src_proc_peak_memory"] = "Src process peak memory (bytes)",
    ["src_proc_pid"] = "Src process PID",
    ["src_proc_uid"] = "Src process UID",
    ["src_proc_user_name"] = "Src process user name",
    ["src_to_dst_avg_throughput"] = "Src to dst average thpt (bps)",
    ["src_to_dst_max_throughput"] = "Src to dst max thpt (bps)",
    ["src_to_dst_min_throughput"] = "Src to dst min thpt (bps)",
    ["src_tos"] = "TOS/DSCP (src->dst)",
    ["src_vlan"] = "Source VLAN (inner VLAN in QinQ)",
    ["ssdp_host"] = "SSDP Host",
    ["ssdp_method"] = "SSDP Method",
    ["ssdp_server"] = "SSDP Server",
    ["ssdp_type"] = "SSDP Type",
    ["ssdp_usn"] = "SSDP USN",
    ["tcp_flags"] = "Kumulativ aller Flow TCP Flags",
    ["tcp_win_max_in"] = "Max TCP Fenster (src->dst)",
    ["tcp_win_max_out"] = "Max TCP Fenster (dst->src)",
    ["tcp_win_min_in"] = "Min TCP Fenster (src->dst)",
    ["tcp_win_min_out"] = "Min TCP Fenster (dst->src)",
    ["tcp_win_mss_in"] = "TCP Max Segmentgrösse (src->dst)",
    ["tcp_win_mss_out"] = "TCP Max Segmentgrösse (dst->src)",
    ["tcp_win_scale_in"] = "TCP Fenster Scale (src->dst)",
    ["tcp_win_scale_out"] = "TCP Fenster Scale (dst->src)",
    ["tls_server_name"] = "TLS Servername",
    ["total_bytes_exp"] = "Total der exportierten Bytes",
    ["total_flows_exp"] = "Total Anzahl der exportierten Flows",
    ["total_pkts_exp"] = "Total der exportierten Flow Paketen",
    ["untunneled_ipv4_dst_addr"] = "Untunneled IPv4 Destinationsadresse",
    ["untunneled_ipv4_src_addr"] = "Untunneled IPv4 source Adresse",
    ["untunneled_ipv6_dst_addr"] = "Untunneled IPv6 Destinationadresse",
    ["untunneled_ipv6_src_addr"] = "Untunneled IPv6 source Adresse",
    ["untunneled_l4_dst_port"] = "Untunneled IPv4 Destinationsport",
    ["untunneled_l4_src_port"] = "Untunneled IPv4 source port",
    ["untunneled_protocol"] = "Untunneled IP Protokoll Byte",
    ["upstream_session_id"] = "Upstream session Kennzeichner (e.g. L2TP) oder 0 wenn unbekannt",
    ["upstream_tunnel_id"] = "Upstream Tunnelkennzeichner (e.g. GTP TEID, VXLAN VNI) oder 0 wenn unbekannt",
    ["user_name"] = "User Name",
  },
  ["flows_page"] = {
    ["active_flows"] = "aktive %{filter} Flows",
    ["actual_throughput"] = "aktuelle Thpt",
    ["alerted"] = "gewarnt",
    ["all_ases"] = "Alle ASes",
    ["all_categories"] = "Alle Kategorien",
    ["all_devices"] = "Alle Flow Exporters",
    ["all_flows"] = "Alle Flows",
    ["all_hosts"] = "Alle Hosts",
    ["all_inIfIdx"] = "Alle Eingabe Interfaces",
    ["all_ip_versions"] = "Alle Versionen",
    ["all_outIfIdx"] = "Alle Ausgabe Interfaces",
    ["all_proto"] = "Alle Proto",
    ["all_vlan_ids"] = "Alle VLANs",
    ["applications"] = "Applikationen",
    ["blocked"] = "blockiert",
    ["client_as"] = "Client AS",
    ["device_ip"] = "Flow Exporter",
    ["direction"] = "Richtung",
    ["flows"] = "%{filter} Flows",
    ["hosts"] = "Hosts",
    ["idle_flows_not_listed"] = "Leere Flüsse nicht gelisted.",
    ["inIfIdx"] = "Eingabe Interface",
    ["ip_version"] = "IP Version",
    ["ipv4_only"] = "nur IPv4 ",
    ["ipv6_only"] = "nur IPv6 ",
    ["local_cli_remote_srv"] = "Local Client - Remote Server",
    ["local_only"] = "nur lokal",
    ["local_srv_remote_cli"] = "Local Server - Remote Client",
    ["multicast"] = "Multicast/Broadcast",
    ["network"] = " [ Network %{network} ]",
    ["non_multicast"] = "nicht-Multicast/Broadcast",
    ["normal"] = "Normal",
    ["one_way_multicast"] = "in einer Richtung Multicast/Broadcast",
    ["one_way_non_multicast"] = "in einer Richtung nicht-Multicast/Broadcast",
    ["outIfIdx"] = "Ausgabe Interface",
    ["recently_active_flows"] = "vor kurzem aktiv %{filter} Flows",
    ["remote_only"] = "nur Remote",
    ["server_as"] = "Server AS",
    ["sflow_devices"] = "sFlow Geräte",
    ["source_id"] = "Source Id",
    ["total_bytes"] = "Total Bytes",
    ["vlan"] = "VLAN",
  },
  ["geo_map"] = {
    ["browser_reported_home_map"] = "Browser hat den Standort der home map angegeben",
    ["geo_map"] = "Geo Map",
    ["geolocation_error"] = "Geolocation Fehler",
    ["hosts_geomap"] = "Hosts GeoMap",
    ["latitude"] = "Breitengrad",
    ["longitude"] = "Längengrad",
    ["note"] = "NOTIZ",
    ["note_active_flows"] = "Aktive Flows haben zwischen Peers mit öffentlichen IP Adressen.",
    ["note_compiled_ntopng_with_geolocation"] = "Sie müssen der software mit geolocation kompiliert haben und damit angefangen.",
    ["note_google_maps_browser_api_key"] = "Ein Google Maps Browser API Schlüssel wird vielleicht benötigt. Detaillierte informationen zur Schlüsselerzeugung <a href='%{url_google}'>kann hier gefunden werden</a>.<br>Wenn generiert, kann der Schlüssel via ntopng eingereicht werden <a href='%{url_prefs}'><i class=\"fas fa-flask\"></i> Preferences</a>.",
    ["note_html_browser_geolocation"] = "HTML <A HREF=%{url}>browser geolocation</A> is used to place on map hosts based on unknown locations.",
    ["note_requirements_visualize_maps"] = "Um die maps zu visualisieren müssen Sie",
    ["note_working_internet_connection"] = "Eine funktionierende Internetverbindung haben.",
    ["unavailable_geolocation"] = "Geolocation wird durch Ihren Browser nicht unterstützt oder deaktiviert.",
    ["using_default_location"] = "Default Standort verwenden.",
  },
  ["graphs"] = {
    ["active_devices"] = "aktive Geräte",
    ["active_flows"] = "aktive Flows",
    ["active_hosts"] = "aktive Hosts",
    ["active_http_servers"] = "aktive HTTP Servers",
    ["arp_replies"] = "ARP Antwort",
    ["arp_requests"] = "ARP Anfrage",
    ["average"] = "Durchschnitt",
    ["average_traffic"] = "Durchschnittlicher Datenverkehr/Sek",
    ["graph_info"] = "Graph Info",
    ["max"] = "Max",
    ["minute_interface_top_stats"] = "Minuten Interface Top Traffic Statistiken",
    ["note_ases_rcvd"] = "Der Datenverkehr hat den vom autonomen System empfangen Datenverkehr erhalten.",
    ["note_ases_sent"] = "Der gesendete Datenverkehr ist der vom autonomen System gesendete Datenverkehr.",
    ["note_ases_traffic"] = "Der angezeigte Datenverkehr wird vom autonomen System gesendet und empfangen.",
    ["note_protocols_shown"] = "Protokolle die im ausgewählten Zeitraum nicht angezeit werden sind nicht im Dropdown Menü aufgeführt.",
    ["num_ms_rtt"] = "Round-Trip Time ms",
    ["packet_drops"] = "Packet Drops",
    ["percentile"] = "95th <a href=\\",
    ["tcp_finack_packets"] = "TCP FIN+ACK Pakete",
    ["tcp_packets_lost"] = "TCP verlorene Pakete",
    ["tcp_packets_ooo"] = "TCP Pakete ausser Betrieb",
    ["tcp_packets_retr"] = "neu übertragene TCP Pakete",
    ["tcp_retr_ooo_lost"] = "TCP neu übertragene, ausser Betrieb und verlorene",
    ["tcp_rst_packets"] = "TCP RST Pakete",
    ["tcp_syn_packets"] = "TCP SYN Pakete",
    ["tcp_synack_packets"] = "TCP SYN+ACK Pakete",
    ["top_profiles"] = "Top Profile",
    ["top_receivers"] = "Top Empfänger",
    ["top_senders"] = "Top Sender",
    ["zmq_received_flows"] = "ZMQ erhaltene Flows",
  },
  ["host_config"] = {
    ["host_alias"] = "Host Alias",
    ["host_pool"] = "Host Pool",
    ["host_traffic_policy"] = "Host Datenverkehrs Policy",
    ["modify_host_pool_policy_btn"] = "Host Pool Policy ändern",
    ["trigger_alerts_for_host"] = "Warnungen auslösen für Host %{host}",
    ["trigger_host_alerts"] = "Hostwarnungen auslösen",
  },
  ["host_details"] = {
    ["blocked_traffic"] = "Blockierter Datenverkehr",
    ["host"] = "Host",
    ["host_cannot_be_found_message"] = "Host %{host} ist unauffindbar.",
    ["host_parameter_missing_message"] = "Host Parameter fehlt (interner Fehler ?)",
    ["host_traffic_blocked_quota_and_shaper"] = "Einiger Host Datenverkehr wurde blockiert durch überschrittene quota und einen blocking sharper",
    ["host_traffic_blocked_shaper"] = "Einiger Host Datenverkehr wurde blockiert durch einen blocking shaper",
    ["snmp"] = "SNMP",
    ["trace_debug_host_info"] = "Host:%{hostinfo}, Vlan: %{vlan}",
    ["trace_debug_host_ip"] = "Host:%{hostip}, Vlan: %{vlan}",
    ["trace_debug_restored_host_info"] = "Wiederhergestellte Host Info",
    ["unknown_device_type"] = "Unbekannter Gerätetyp",
  },
  ["host_pools"] = {
    ["alias_or_manufacturer"] = "Alias / Manufacturer",
    ["and_associated_members"] = "es ist RRD data und alle assozierten Mitglieder",
    ["cannot_delete_cp"] = "Ein pool kann nicht gelöscht werden wenn kein Captive Portal Benutzer assoziert ist",
    ["change_member_pool"] = "Mitglied Pool wechseln",
    ["change_pool"] = "Switch Pool",
    ["children_safe"] = "Sichere Suche",
    ["confirm_delete_pool"] = "Wollen Sie wirklich den Host pool löschen",
    ["confirm_empty_pool"] = "Wollen Sie wirklich alle Mitglieder vom host pool entfernen",
    ["confirm_remove_member"] = "Wollen Sie wirklich Mitglied entfernen",
    ["confirm_reset_pool_quotas"] = "Wollen Sie wirklich die Zählen vom Pool \"%{pool}\" zurücksetzen?",
    ["confirm_reset_quotas"] = "Wollen Sie wirklich alle Quoten zurücksetzen ?",
    ["create_new_quotas_here"] = "Wollen Sie hier eine neue Quote <a href=\"%{url}\">erzeugen</a>.",
    ["create_pool_hint"] = "Vom Manage Pools tab können neue Pools kreirt werden.",
    ["create_pools"] = "Manage Pools",
    ["delete_pool"] = "Pool löschen",
    ["duplicate_member"] = "Mitglied Adresse verdoppeln",
    ["duplicate_pool"] = "Pool Name verdoppeln",
    ["edit_host_pools"] = "Edit Host Pools",
    ["empty_pool"] = "Pool leeren",
    ["enforce_quotas_per_pool_member"] = "Pro-Mitglied Quotas",
    ["enforce_shapers_per_pool_member"] = "Pro-Mitglied Shapers",
    ["from_pool"] = "von host pool",
    ["host_pools"] = "Host Pools",
    ["invalid_member"] = "Ungültiges Mitglied Adress Format",
    ["manage_pools"] = "Manage Pool Mitglied",
    ["manufacturer_filter"] = "Manufacturer: %{manufacturer}",
    ["max_members_message"] = "Mit dieser ntopng Version kann man nur %{maxnum} Mitglieder pro host pool zuteilen. Upgrade zur enterprise Version um diese Limite zu entfernen.",
    ["max_pools_message"] = "Mit dieser ntopng Version kann man nur %{maxnum} Host pools kreiren. Upgrade zur enterprise Version um diese Limite zu entfernen.",
    ["member_address"] = "Mitglied Adresse",
    ["member_exists"] = "Mitglied \"%{member_name}\" nicht hinzugefügt. Es ist schon zugeteilt an pool \"%{member_pool}\".",
    ["member_filter"] = "Mitglied: %{member}",
    ["members_limit_reached"] = "Mitgliederlimite erreicht",
    ["network_normalized"] = "Netzwerk \"%{network}\" hat ein non-zero host identifier. Brauchen \"%{network_normalized}\".",
    ["new_pool"] = "Neuer Pool",
    ["no_pools_defined"] = "Host Pools nicht definiert.",
    ["per_member_quotas"] = "Wenn die Option pro Mitglied quotas festgelegt ist, wird jeder Host eine separate Anzahl von quotas haben. Wenn nicht festgesetzt, wird der gesamte Datenverkehr des Hosts als Ganzes auf das quota Limit angerechnet",
    ["per_member_shapers"] = "Wenn die Option für die Shapers pro Mitglied festgelegt ist, verfügt jeder Host über eigene Shaper. Wenn nicht festgesetzt, werden alle Hosts, die zu demselben Pool gehören, dieselben Shaper verwenden",
    ["pool"] = "Pool Name",
    ["pool_name"] = "Pool Name",
    ["pool_name_pattern_error"] = "Bitte nur Kleinbuchstaben, Nummern oder Underscore eingeben.",
    ["remove_member"] = "Mitglied entfernen",
    ["reset_quotas"] = "Quotas zurücksetzen",
    ["search_member"] = "Mitgliedsuche",
    ["select_new_pool"] = "Wählen Sie einen neuen Pool aus dem Dropdown Menü aus, um ein Mitglied zuzuweisen \"%{member}\" an:",
    ["specify_member_address"] = "Eine IPv4/IPv6 Adresse oder Netzwerk oder MAC Adresse angeben",
    ["specify_pool_name"] = "Einen Pool Name spezifizieren",
    ["view"] = "Sicht",
  },
  ["hosts_comparison"] = {
    ["hosts_parameter_missing_message"] = "Hosts parameter fehlt (internal error ?)",
  },
  ["hosts_stats"] = {
    ["all"] = "Alle",
    ["all_hosts"] = "Alle Hosts",
    ["as_geolocation"] = "AS Geolocation",
    ["as_info"] = "AS Info",
    ["as_path"] = "AS Path",
    ["as_prefixes"] = "AS Prefixes",
    ["asn_title"] = "für AS %{asn}",
    ["bgp_updates"] = "BGP Updates",
    ["blacklisted"] = "Blacklisted",
    ["blacklisted_hosts_only"] = "Nur Blacklisted Hosts",
    ["blocking_traffic_policy_popup_msg"] = "Host Datenverkehr ist von einer Sperrung Traffic Policy betroffen",
    ["country_title"] = "für Land %{country}",
    ["filter_hosts"] = "Filter Hosts",
    ["filtered"] = "Gefiltert",
    ["filtered_hosts_only"] = "Hosts mit blockiertem Datenverkehr",
    ["host_pool"] = "Host Pool %{pool_name}",
    ["hosts"] = "Hosts",
    ["hosts_page_title"] = "%{all} %{local_remote} %{protocol} %{network} %{ip_version} %{os} Hosts %{country_asn_or_mac} %{vlan}",
    ["idle_hosts_not_listed"] = "Idle hosts nicht aufgeführt.",
    ["in_network"] = "in %{network}",
    ["ipver_title"] = "IPv%{version_num}",
    ["label_blacklisted_host"] = "Host auf schwarzer Liste",
    ["label_local_host"] = "Lokaler Host",
    ["label_remote_host"] = "Remote Host",
    ["local"] = "Lokal",
    ["local_hosts_only"] = "Nur lokale Hosts",
    ["location"] = "Location",
    ["mac_title"] = "mit Mac %{mac}",
    ["more_info_about_as_popup_msg"] = "Mehr Information über AS",
    ["pool_title"] = "für Pool %{poolname}",
    ["remote"] = "Remote",
    ["remote_hosts_only"] = "Nur Remote Hosts",
    ["source_id"] = "Source Id",
    ["user"] = "User %{pool_name}",
    ["user_title"] = "für User %{poolname}",
    ["vlan_title"] = "VLAN %{vlan}",
  },
  ["http_page"] = {
    ["distribution"] = "Verteilung",
    ["http_queries"] = "HTTP Anfragen",
    ["http_responses"] = "HTTP Antworten",
    ["method"] = "Methode",
    ["other_method"] = "Andere Methode",
    ["requests"] = "Anfragen",
    ["requests_served"] = "Anfragen Served",
    ["response_code"] = "Antworts code",
    ["response_code_1xx"] = "1xx (Informational)",
    ["response_code_2xx"] = "2xx (Success)",
    ["response_code_3xx"] = "3xx (Redirection)",
    ["response_code_4xx"] = "4xx (Client Error)",
    ["response_code_5xx"] = "5xx (Server Error)",
    ["responses"] = "Antworten",
    ["traffic_received"] = "Erhaltener Datenverkehr",
    ["traffic_sent"] = "Gesendeter Datenverkehr",
    ["virtual_hosts"] = "Virtual Hosts",
  },
  ["http_servers_stats"] = {
    ["actual_requests"] = "Aktuelle Anfragen",
    ["bytes_received"] = "Erhaltene Bytes",
    ["bytes_sent"] = "Gesendete Bytes",
    ["http_server_ip"] = "HTTP Server IP",
    ["http_servers"] = "Server HTTP",
    ["http_virtual_host"] = "HTTP Virtual Host",
    ["local_http_servers"] = "Lokale HTTP Servers",
    ["total_requests"] = "Total Anfragen",
  },
  ["icmp_page"] = {
    ["icmp_message"] = "ICMP Nachricht",
    ["last_rcvd_peer"] = "Letzter Rcvd Peer",
    ["last_sent_peer"] = "Letzter gesendeter Peer",
    ["packets_received"] = "Erhaltene Pakete",
    ["packets_sent"] = "Gesendete Pakete",
  },
  ["if_stats_config"] = {
    ["custom_name"] = "Custom Name",
    ["custom_name_popup_msg"] = "Eine alias für die interface spezifizieren",
    ["interface_network_discovery"] = "Periodische Interface Netzwerk Discovery",
    ["interface_speed"] = "Interface Geschwindigkeit (Mbit/s)",
    ["interface_speed_popup_msg"] = "Maximale interface Geschwindigkeit spezifizieren",
    ["scaling_factor"] = "Eingangspakete Sampling Rate",
    ["scaling_factor_popup_msg"] = "Dies sollte mit Ihrer capture interface sampling rate übereinstimmen",
    ["trigger_interface_alerts"] = "Interface Warnungen auslösen",
  },
  ["if_stats_overview"] = {
    ["active"] = "Aktive",
    ["all_counters"] = "Alle Counters",
    ["bridged_traffic"] = "Bridged Datenverkehr",
    ["buffer_full"] = "Voller Buffer",
    ["collected_flows"] = "Gesammelte Flows",
    ["dropped_flows"] = "Dropped Flows",
    ["dropped_packets"] = "Dropped Pakete",
    ["drops_only"] = "Nur Drops",
    ["dumped_files"] = "Dumped Files",
    ["dumped_packets"] = "Dumped Pakete",
    ["egress_packets"] = "Ausgangspakete",
    ["exported_flows"] = "Exportierte Flows",
    ["family"] = "Familie",
    ["flows_export_statistics"] = "Flows Export Statistiken",
    ["has_traffic_directions"] = "mit RX/TX Richtungen",
    ["id"] = "Id",
    ["iface_switch_active_msg"] = "Die ausgewählte interface <b>%{interface}</b> [ifid: %{ifid}] ist jetzt aktiv",
    ["iface_switch_empty_session_msg"] = "Leere Session",
    ["iface_switch_error_msg"] = "Fehler beim Wechseln der interfaces",
    ["in_path_interface"] = "In-Path Interface (Bump in the Wire)",
    ["ingress_packets"] = "Eingangspakete",
    ["ingress_traffic"] = "Eingangsdatenverkehr",
    ["interface_ip"] = "Interface IP",
    ["interface_name"] = "Interface Name",
    ["interface_rx_updates"] = "Interface RX Updates",
    ["note"] = "NOTIZ",
    ["note_drop_ifstats_dynamic"] = "Drops sind verfügbar in der main interface",
    ["note_drops_sflow"] = "Drops werden nur für sFlow gemeldet da NetFlow diese nicht meldet.<br>In <A HREF=https://www.ietf.org/rfc/rfc3176.txt>sFlow</A> drops werden nach drops value part der flow sample berechnet.",
    ["note_packets"] = "Im Ethernet Netzwerk hat jedes Paket ein <A HREF=\"https://en.wikipedia.org/wiki/Ethernet_frame\">overhead of 24 bytes</A> [preamble (7 bytes), start of frame (1 byte), CRC (4 bytes), and <A HREF=\"http://en.wikipedia.org/wiki/Interframe_gap\">IFG</A> (12 bytes)]. Ein solcher Overhead muss dem interface Verkehr zugeordnet werden, wird jedoch nicht zum Verkehr zwischen IP Adressen hinzugefügt. Dies liegt daran, dass solche Daten zur interface load beitragen, aber nicht im Datenverkehr, der von Hosts ausgetauscht wird, daher können geringe Abweichungen zwischen Host und interface traffic values erwartet werden.",
    ["paused"] = "In Pause",
    ["probe_ip"] = "Probe IP",
    ["probe_timeout_idle"] = "Idle Timeout",
    ["probe_timeout_lifetime"] = "Lebensdauer Timeout",
    ["probe_zmq_num_endpoints"] = "Aktiver Probe ZMQ Endpoints",
    ["probe_zmq_num_flow_exports"] = "Exportierte Flows",
    ["public_probe_ip"] = "Public Probe IP",
    ["received_traffic"] = "Erhaltener Datenverkehr",
    ["remote_probe"] = "Remote Probe",
    ["reset_counters"] = "Reset Counters",
    ["send_error"] = "Fehler senden",
    ["sflow_counter_updates"] = "sFlow Zähler Updates",
    ["shaped_filtered_packets"] = "Shaped/Filtered Packets",
    ["snmp"] = "SNMP",
    ["state"] = "State",
    ["traffic_breakdown"] = "Datenverkehrs Breakdown",
    ["zmq_message_drops"] = "ZMQ Nachricht Drops",
    ["zmq_rx_statistics"] = "ZMQ RX Statistiken",
  },
  ["index_page"] = {
    ["applications"] = "Applikationen",
    ["asns"] = "ASNs",
    ["dashboard"] = "Dashboard",
    ["hosts"] = "Hosts",
    ["live_update"] = "Live update",
    ["minute"] = "Minuten",
    ["never"] = "Nie",
    ["no_packet_warning"] = "In der Interface wurde noch kein Paket empfangen %{ifname}.<p>Please wait %{countdown} Sekunden bis diese Seite neu geladen wird.",
    ["refresh"] = "Aktualisieren",
    ["refresh_frequency"] = "Aktualisierungsfrequenz",
    ["refresh_graph_popup_msg"] = "Grafik aktualisieren",
    ["seconds"] = "Sekunden",
    ["senders"] = "Sender",
    ["top_flow_talkers"] = "Top Flow Talkers",
  },
  ["local_flow_matrix"] = {
    ["error_no_local_hosts"] = "Keine lokalen Hosts gefunden",
    ["local_flow_matrix"] = "Lokale Matrix lang. Flüsse",
    ["local_hosts_active_flows_matrix"] = "Lokale Hosts Aktive Flows Matrix",
  },
  ["local_hosts_stats"] = {
    ["criteria"] = "Kriterien",
    ["looking_glass"] = "Looking Glass",
  },
  ["locales"] = {
    ["de"] = "Deutsch",
    ["en"] = "Englisch",
    ["it"] = "Italienisch",
    ["jp"] = "Japanisch",
  },
  ["login"] = {
    ["add_captive_portal_user"] = "Füge Captive Portal User hinzu",
    ["add_web_user"] = "Web User hinzufügen",
    ["auth_success"] = "Authentifizierung erfolgreich",
    ["change_password"] = "Passwort ändern",
    ["confirm_password"] = "Passwort bestätigen",
    ["device_label"] = "Device Label",
    ["enter_credentials"] = "Bitte geben Sie Ihre Zugangsdaten für den Zugriff auf dieses Netzwerk ein.",
    ["internet_redirecting"] = "Wir leiten Sie zum Internet weiter...",
    ["license"] = "%{product} is released under <a href=\"%{license_url}\">%{license}</a>.",
    ["logging_out"] = "Ausloggen...",
    ["login"] = "Anmeldung",
    ["logout"] = "Ausloggen",
    ["logout_user_x"] = "Abmellang. %{user}",
    ["must_change_password"] = "Das Standard Admin Passwort muss geändert werden. Bitte geben Sie unten ein neues Passwort ein.",
    ["password"] = "Passwort",
    ["password_mismatch"] = "Passwörter stimmen nicht überein",
    ["password_not_valid"] = "Bitte geben Sie ein anderes Passwort an",
    ["password_pattern_error"] = "Bitte mindestens 5 gültige Charakter eingeben.",
    ["password_ph"] = "Kennwort (default admin)",
    ["passwords_dont_match"] = "Password stimmt nicht überein.",
    ["username"] = "Benutzername",
    ["username_ph"] = "Benutzername (default admin)",
    ["web_users"] = "Web Users",
    ["welcome_to"] = "Willkommen %{product}",
  },
  ["mac_details"] = {
    ["mac"] = "Mac",
    ["mac_cannot_be_found_message"] = "Mac %{mac} ist unauffindbar.",
    ["mac_parameter_missing_message"] = "Mac Parameter fehlt (interner Fehler ?)",
  },
  ["mac_stats"] = {
    ["all_devices"] = "Alle Geräte",
    ["all_layer_2_devices"] = "Alle Geräte",
    ["all_manufacturers"] = "Alle Hersteller",
    ["arp_total"] = "ARP",
    ["dev_layer_2_devices"] = "%{device_type} Geräte",
    ["dhcp_only"] = "Nur DHCP",
    ["filter_macs"] = "Filter MACs",
    ["idle_devices_not_listed"] = "Idle Geräte nicht aufgeführt.",
    ["layer_2_dev_devices"] = "%{device_type} Geräte",
    ["layer_2_devices_with_manufacturer"] = "%{title} vom '%{manufacturer}' Hersteller",
    ["manufacturer"] = "Hersteller",
  },
  ["manage_users"] = {
    ["add_new_user"] = "Neuen User hinzufügen",
    ["administrator"] = "Administrator",
    ["allowed_interface"] = "Erlaubte Interface",
    ["allowed_networks"] = "Erlaubte Netzwerke",
    ["allowed_networks_descr"] = "Komma getrennte Liste von Netzwerken, welche lang. User anzeigen darf. Beispiel:",
    ["allowed_passwd_charset"] = "Erlaubte Charakter sind ISO 8859-1 (latin1) Gross- und Kleinbuchstaben, Nummern und spezielle Symbole",
    ["any_interface"] = "Jelang. Interface",
    ["authentication_lifetime"] = "Authentifizierungslebensdauer",
    ["change_user_password"] = "Änlang.e User Password",
    ["change_user_preferences"] = "Änlang.e User Einstellungen",
    ["confirm_delete_user"] = "Sind Sie sicher lang. %{user} löschen zu wollen?",
    ["enable_captive_portal"] = "<a href=\\",
    ["expires_after"] = "Verfällt nach",
    ["group"] = "Gruppe",
    ["host_pool_id"] = "Host Pool Id",
    ["manage"] = "Verwalten",
    ["manage_user_x"] = "Verwalte User %{user}",
    ["manage_users"] = "Userverwaltung",
    ["new_password"] = "Neues Password",
    ["new_password_confirm"] = "Bestätige neues Password",
    ["no_host_pools"] = "Kein Host Pools lang.iniert. Bitte erzeuge einen <a href='%{url}'>here</a>",
    ["non_privileged_user"] = "Kein berechtigter User",
    ["old_password"] = "Altes Password",
    ["the_auth_can_be_perpetual"] = "Die Authentifizierung kann dauerhaft sein olang. sie kann nach spezifizierter Zeit verfallen",
    ["the_host_pool_associated"] = "Der host pool, welcher lang. User nach erfolgreicher Authentifizierung zugeordnet wird.",
    ["unlimited"] = "Unbegrenzt",
    ["user_role"] = "User Rolle",
    ["web_captive_users"] = "Web/Captive Portal User",
  },
  ["metrics"] = {
    ["days"] = "Days",
    ["hours"] = "Stunlang.",
    ["mins"] = "Min",
    ["secs"] = "Sek",
  },
  ["ndpi_page"] = {
    ["live_flows_count"] = "Live Flows Count",
    ["note"] = "NOTIZ",
    ["note_historical_per_protocol_traffic"] = "Historische %{what} Datenverkehr kann durch ntopng aktiviert werden <a href='%{url}'>%{flask_icon} Preferences</a>.",
    ["note_live_flows_chart"] = "Dieses Diagramm zeigt nur TCP Verbindungen.",
    ["note_possible_probing_alert"] = "Eine icon wie %{icon} zeigt eine mögliche probing (oder Applikationsserver ist unten) Warnung an da der Host Datenverkehr erhalten hat für ein bestimmtes Anwendungsprotokoll ohne Daten zurückzusenden. Sie können dies gebrauchen <A HREF='%{url}'>historical reports</A> to drill-down this issue.",
    ["note_protocol_usage_time"] = "Die Protokollnutzungszeit wird in diskreten Zeitintervallen berechnet.",
    ["overview"] = "%{what} Übersicht",
    ["rcvd"] = "Rcvd",
    ["received_only"] = "Nur erhalten",
    ["sent"] = "Gesendet",
    ["sent_only"] = "Nur gesendet",
    ["total_since_startup"] = "Total (Seit Startup)",
    ["unable_to_find_host"] = "Unfähig zu finden %{host_ip} (data expired ?)",
  },
  ["network_alert_config"] = {
    ["trigger_alerts_for_network"] = "Trigger Alarme für Netzwerk %{network}",
    ["trigger_network_alerts"] = "Trigger Netzwerk Alarme",
  },
  ["network_details"] = {
    ["network"] = "Netzwerk",
    ["network_parameter_missing_message"] = "Netzwerk Parameter fehlt (interner Fehler?)",
    ["no_available_stats_for_network"] = "Keine verfügbaren Statistiken für das Netzwerk %{network}",
  },
  ["network_stats"] = {
    ["network_list"] = "Netzwerkliste",
    ["network_name"] = "Netzwerkname",
    ["networks"] = "Netzwerke",
    ["networks_traffic_with_ipver"] = "%{networks} with IPv%{ipver} traffic",
    ["note_broader_network"] = "Das broader Netzwerk umfasst keine Hosts, die in kleineren Netzwerken definiert sind.",
    ["note_overlapping_networks"] = "NOTIZ: Falls Sie überlappende Netzwerke definiert haben:",
    ["note_see_both_network_entries"] = "Sie werden beide Netzwerkeinträge in der obigen Tabelle sehen.",
  },
  ["os_stats"] = {
    ["hosts_by_operating_system"] = "Hosts nach Betriebssystem",
  },
  ["packets_page"] = {
    ["arp_distribution"] = "ARP Verteilung",
    ["ip_version_distribution"] = "IP Version Verteilung",
    ["lost"] = "Verloren",
    ["out_of_order"] = "Ausser Betrieb",
    ["received_distribution"] = "Erhaltene Verteilung",
    ["retransmissions"] = "Retransmissions",
    ["sent_distribution"] = "Gesendete Verteilung",
    ["sent_vs_rcvd_distribution"] = "Sent vs Rcvd Verteilung",
    ["size_distribution"] = "Grössenverteilung",
    ["tcp_flags_distribution"] = "TCP Flags Verteilung",
    ["tcp_flags_vs_arp_distribution"] = "TCP Flags / ARP Vertailung",
    ["tcp_packets_analysis"] = "TCP Paketsanalyse",
    ["version_vs_flags_distribution"] = "IP version / TCP Flags Vertailung",
  },
  ["peers_page"] = {
    ["host"] = "Host",
    ["no_active_flows_message"] = "Für diesen Host sind keine aktiven Flows beobachtet worden",
    ["top_peer_protocol"] = "Top Peer Protokolle",
    ["top_peers_for_host"] = "Top %{hostkey} Peers",
    ["traffic_volume"] = "Datenverkehrsvolumen",
  },
  ["please_wait_page"] = {
    ["command"] = "Command",
    ["database"] = "Datenbank",
    ["host"] = "Host",
    ["id"] = "Id",
    ["info"] = "Info",
    ["operations_on_database_msg"] = "Die derzeit in der Datenbank ausgeführten Operationen sind die folgenden: ",
    ["state"] = "Zustand",
    ["time"] = "Zeit",
    ["user"] = "Benutzer",
    ["waiting_for_db_msg"] = "Migration des Datenenbankschemas in Bearbeitung, warten auf Datenbank <b>%{dbname}</b> geht in Betrieb. Sie werden umgeleitet sobald die Datenbank bereit ist. Abhängig von der Grösse der vorhandenen Datenbank kann diese Operation sehr lange dauern. Migrationen werden nur einmal und nur bei grösseren Versionsupgrades durchgeführt. Im Zweifelsfall kontaktieren Sie bitte die Entwickler unter <a href='mailto:info@ntop.org'>info@ntop.org</a>.",
  },
  ["policy_presets"] = {
    ["business"] = "Business",
    ["business_description"] = "Eine Voreinstellung für Mitarbeiter von Geschäftsunternehmen",
    ["child"] = "Kind",
    ["child_description"] = "Eine Voreinstellung für Kinder. Blockiert social Netzwerke und begrenzt die Spielzeit",
    ["default"] = "Standard",
    ["guests"] = "Gäste",
    ["guests_description"] = "Eine Voreinstellung für Gäste. Es ist nur einfache Navigation erlaubt",
    ["no_obfuscation"] = "No Obfuscation",
    ["no_obfuscation_description"] = "Eine Voreinstellung um Datenverkehrs obfuscation zu verhindern",
    ["walled_garden"] = "Walled Garden",
    ["walled_garden_description"] = "Blockiert VPN und social Netzwerke",
  },
  ["pool_details"] = {
    ["host_pool"] = "Host Pool",
    ["host_pool_timeseries_enable_message"] = "Host Pool timeseries können aktiviert werden von <A HREF=\"%{url}\">%{icon_flask} Preferences</A>. Einige Minuten sind notwendig um die ersten Datenpunkte zu sehen.",
    ["no_available_data_for_host_pool_message"] = "Keine verfügbare Data für den Host Pool '%{pool_name}'.",
    ["pool_parameter_missing_message"] = "Pool Parameter fehlt (interner Fehler ?)",
  },
  ["pool_stats"] = {
    ["host_pool_list"] = "Host Pool Liste",
  },
  ["port_details"] = {
    ["active_flows_for_host_and_port"] = "Aktive Flows für %{host}:%{port}",
    ["active_flows_on_port"] = "Aktive Flows auf Port %{port}",
    ["active_flows_on_port_symbolic"] = "Aktive Flows auf Port %{port} [%{symbolic_port}]",
    ["l4_port"] = "L4 Port",
  },
  ["ports_page"] = {
    ["client_ports"] = "Client Ports",
    ["server_ports"] = "Server Ports",
  },
  ["prefs"] = {
    ["active_local_host_cache_interval_description"] = "Intervall zwischen aufeinanderfolgenden aktiven lokalen Hostcache Dumps. Default: 1 Stunde.",
    ["active_local_host_cache_interval_title"] = "Aktiver lokaler Host Cache Intervall",
    ["admin_group_description"] = "Gruppenname zu der der Benutzer gehören muss um sich als Administrator zu authentifizieren.",
    ["admin_group_title"] = "LDAP Admin Gruppe",
    ["alerts_retention"] = "Alarme Retention",
    ["all"] = "Alle",
    ["authentication"] = "Authentifikation",
    ["bind_dn_description"] = "Bind Distinguished Name des LDAP Servers. Example:",
    ["bind_dn_title"] = "LDAP Bind DN",
    ["bind_pwd_description"] = "Bind Kennwort für die Authentifizierung mit dem LDAP Server.",
    ["bind_pwd_title"] = "LDAP Bind Authentifizierungs Kennwort ",
    ["both"] = "Beide",
    ["cache_settings"] = "Cache Settings",
    ["captive_portal_url_description"] = "Der URL zu der Ihre Clients nach einer erfolgreichen captive protal Authentifizierung weitergeleitet werden.",
    ["captive_portal_url_title"] = "Umleitung URL",
    ["default_snmp_community_description"] = "Die default SNMP community wird verwendet wenn versucht wird die SNMP MIB eines ausgewählten lokalen Hosts welcher nicht durch die SNMP Geräte Seite konfiguriert wurde.",
    ["default_snmp_community_title"] = "Default SNMP Community",
    ["default_snmp_proto_version_description"] = "Die Standardversion des SNMP-Protokolls.",
    ["default_snmp_proto_version_title"] = "Standard SNMP Version",
    ["disable_alerts_generation_description"] = "Schalten Sie auf overall Generierung von Alarmen um.",
    ["disable_alerts_generation_title"] = "Alarme aktivieren",
    ["dns"] = "DNS",
    ["dns_service"] = "Service",
    ["dynamic_interfaces_creation_description"] = "ntopng kann ein Kriterium verwenden, um eingehenden Datenverkehr zu disaggreggieren. Wenn ein Disaggregationskriterium ausgewählt wird, verwendet ntopng den Kriteriumswert, um eingehenden Datenverkehr an dynamisch erstelle Interfaces umzuleiten. Wenn beispielsweise, das VLAN Id Kriterium ausgewählt ist, wird für jede beobachtete VLAN id eine dynamische Interface erstellt, und der eingehende Datenverkehr wird je nach VLAN id Wert an eine dynamische Interface umgeleitet. ",
    ["dynamic_interfaces_creation_note_0"] = "VLAN Id disaggregation wird sowohl für physische Interfaces als auch für Flows unterstützt, die über ZMQ empfangen werden. Die anderen Disaggregationskriterien werden nur für ZMQ Flows unterstützt und sind für physische Interfaces ineffektiv.",
    ["dynamic_interfaces_creation_note_1"] = "Kriterienänderunge wirken sich nicht auf vorhandene Interfaces aus..",
    ["dynamic_interfaces_creation_note_2"] = "Wenn Ingress Interface Kriterien an nicht-sflow Geräte verwendet wird, %%INPUT_SNMP muss im nprobe Template definiert sein.",
    ["dynamic_interfaces_creation_title"] = "Disaggregationskriterium",
    ["dynamic_network_interfaces"] = "Dynamische Netzwerk Interfaces",
    ["errors"] = "Fehler",
    ["errors_and_warnings"] = "Fehler und Warnungen",
    ["ewma_alpha_percent_description"] = "Exponentially Weighted Moving Average (EWMA) alpha Koeffizient, dargestellt als Prozentsazt. Verwendet für die Schätzung des rount-trip time vom Autonomous Systems.",
    ["ewma_alpha_percent_title"] = "EWMA alpha Koeffizient (Prozent)",
    ["expert_view"] = "Expert Sicht",
    ["featured_dns_description"] = "Folgendes ist eine Liste der sicheren DNS Server. Sie könenn diese als global DNS Server oder als sicherer Suchanbieter verwenden.",
    ["featured_dns_title"] = "Empfohlene DNS Servers",
    ["flow_max_idle_description"] = "Inaktivitätszeit nach der ein Flow als idle betrachtet wird. Default: 1 min.",
    ["flow_max_idle_title"] = "Flow Idle Timeout",
    ["global_dns_description"] = "Ein DNS Server zum Umleiten der DNS Anforderungen des Clients an nicht sichere Such host pools. Wenn diese Option leer ist wird die Umleitung deaktiviert und das default DNS wird verwendet.",
    ["global_dns_title"] = "Global Primary DNS",
    ["host_mask"] = "Mask Host IP Adressen",
    ["idle_timeout_settings"] = "Idle Timeout Einstellungen",
    ["ingress_flow_interface"] = "Eingangs Interface",
    ["ingress_vrf_id"] = "Eingang VRF Id",
    ["interfaces_timeseries"] = "Interfaces Timeseries",
    ["internal_log"] = "Internal Log",
    ["l2_devices_timeseries"] = "Geräte Timeseries",
    ["ldap_server_address_description"] = "IP Adresse und port vom LDAP Server (e.g. ldaps://localhost:636). Default: \"ldap://localhost:389\".",
    ["ldap_server_address_title"] = "LDAP Server Adresse",
    ["local_host_cache_duration_description"] = "Zeit nachdem ein cached lokaler Host vom cache gelöscht wird. Default: 1 Stunde.",
    ["local_host_cache_duration_title"] = "Lokal Hosts Cache Dauer",
    ["local_host_mask"] = "Mask Local Hosts",
    ["local_host_max_idle_description"] = "Inaktivitätszeit, nach der ein lokaler Host als idle betrachtet wird (sec). Idle lokale Hosts werden in einen Cache ausgelagert, sodass ihre Zähler wiederhergestellt werden können, falls sie wieder aktiv werden Zähler umfassen, sind aber nicht beschränkt auf Pakete und Bytes Total und pro Layer-7 Applikation. Default: 5 min.",
    ["local_host_max_idle_title"] = "Lokaler Host Idle Timeout",
    ["local_hosts_cache_settings"] = "Lokale Hosts Cache Einstellungen",
    ["local_hosts_timeseries"] = "Lokale Hosts Timeseries",
    ["logging"] = "Logging",
    ["max_num_bytes_per_tiny_flow_description"] = "Die maximale Anzahl der Bytes welche ein Flow haben muss um als winziger Flow betrachtet zu werden. Default: 64.",
    ["max_num_bytes_per_tiny_flow_title"] = "Maximale Anzahl der Bytes per Tiny Flow",
    ["max_num_packets_per_tiny_flow_description"] = "Die maximale Anzahl der Pakete welche ein Flow haben muss um als winziger Flow betrachtet zu werden. Default: 3.",
    ["max_num_packets_per_tiny_flow_title"] = "Maximale Anzahl der Pakete per Tiny Flow",
    ["max_ui_strlen_description"] = "Verkürzen Sie Strings die länger sind als die angegebene maximale Anzahl von Zeichen sind.",
    ["max_ui_strlen_title"] = "Maximale angezeigte Stringlänge",
    ["misc"] = "Misc",
    ["multiple_ldap_account_type_description"] = "Wählen Sie Ihren account typ",
    ["multiple_ldap_account_type_title"] = "LDAP Accounts Typ",
    ["mysql"] = "MySQL",
    ["network_discovery"] = "Netzwerk Discovery",
    ["network_discovery_interval_description"] = "Intervall zwischen aufeinander folgenen Entdeckungen von Netzwerken. Default: 15 Min.",
    ["network_discovery_interval_title"] = "Aktives Netzwerkerkennungsintervall",
    ["network_interfaces"] = "Netzwerk Interfaces",
    ["no_host_mask"] = "Don't Mask Hosts",
    ["non_local_host_max_idle_description"] = "Inaktivitätszeit, nach der ein remote Host als idle betrachtet wird. Default: 1 min.",
    ["non_local_host_max_idle_title"] = "Remote Host Idle Timeout",
    ["none"] = "Keine",
    ["other_timeseries"] = "Andere Timeseries",
    ["per_category"] = "Pro Kategorie",
    ["per_protocol"] = "Pro Protokoll",
    ["posix"] = "Posix",
    ["preferences"] = "Einstellungen",
    ["primary_dns"] = "Primary DNS",
    ["probe_ip_address"] = "Probe IP",
    ["protocols"] = "Protokolle",
    ["remote_host_mask"] = "Mask Remote Hosts",
    ["report"] = "Report",
    ["safe_search_dns_description"] = "Der DNS Server welcher verwendet werden soll <a href='%{url}'>Safe Search</a> queries.<br>Die sichere Suche kann für einzelne Host pools über die Konfigurationsseite des Host pools aktiviert werden. Default: 208.67.222.123.",
    ["safe_search_dns_title"] = "Sichere Suche DNS",
    ["samaccount"] = "sAMAccount",
    ["search_path_description"] = "Root Pfad zum Suchen der Benutzer.",
    ["search_path_title"] = "LDAP Suchpfad",
    ["search_preferences"] = "Suche Vorzüge",
    ["secondary_dns"] = "Secondary DNS",
    ["secondary_dns_description"] = "Ein Fallback DNS Server der verwendet werden soll wenn der globale primäre DNS Server nicht verfügbar ist.",
    ["secondary_dns_title"] = "Global Secondary DNS",
    ["security_alerts"] = "Sicherheitsalarme",
    ["sender_username_description"] = "Den Benutzername des Senders von slack Benachrichtigungen setzen",
    ["sender_username_title"] = "Benachrichtigung Sender Benutzername",
    ["simple_view"] = "Einfache Sicht",
    ["slack_integration"] = "Slack Integration",
    ["slack_notification_severity_preference_description"] = "Fehler (nur Fehler), Fehler und Warnungen (Fehler und Warnungen, keine Info), Alle (jede Art von Warnungen wird benachrichtigt).",
    ["slack_notification_severity_preference_title"] = "Notification Preference basierend auf Schweregrad",
    ["slack_webhook_description"] = "Senden Sie Ihre Benachrichtigung an diesen slack URL",
    ["slack_webhook_title"] = "Benachrichtigung Webhook",
    ["snmp"] = "SNMP",
    ["timeseries"] = "Timeseries",
    ["toggle_access_log_description"] = "Schalte die Erstellung des HTTP access log im Data-Dump-Verzeichnis um. Einstellungen werden beim nächsten %{product} Start wirksam.",
    ["toggle_access_log_title"] = "Aktiviere HTTP Access Log",
    ["toggle_active_local_host_cache_enabled_description"] = "Schalten Sie auf Kreation von cache Einträgen für aktive lokale Hosts um. Caching active local hosts periodically can be useful to protect host counters against failures (e.g., power losses). This is particularly important for local hosts that seldomly go idle as it guarantees that their counters will be cached after the specified time interval.",
    ["toggle_active_local_host_cache_enabled_title"] = "Aktive lokale Hosts Cache",
    ["toggle_alert_syslog_description"] = "Aktiviere Alarme logging on system syslog.",
    ["toggle_alert_syslog_title"] = "Alarme On Syslog",
    ["toggle_asn_rrds_description"] = "Schalten Sie auf Kreation der Bytes und Applikation timeseries für autonome Systeme um..",
    ["toggle_asn_rrds_title"] = "Autonomous Systems",
    ["toggle_autologout_description"] = "Aktivieren Sie die automatische Abmeldung von Webinterface Benutzern mit abgelaufenen Sessions.",
    ["toggle_autologout_title"] = "Auto Logout",
    ["toggle_captive_portal_description"] = "Aktivieren des Web captive portal um Netzwerkbenutzer zu authentifizieren.",
    ["toggle_captive_portal_title"] = "Captive Portal",
    ["toggle_dst_with_post_nat_dst_description"] = "Ersetzen Sie IPv4 Destinationsadressen (%%IPV4_DST_ADDR) und ports (%%L4_DST_PORT) mit deren post-nat values (%%POST_NAT_DST_IPV4_ADDR and %%POST_NAPT_DST_TRANSPORT_PORT).",
    ["toggle_dst_with_post_nat_dst_title"] = "Post-Nat Destinations IPv4 Adressen und Ports benutzen",
    ["toggle_flow_rrds_description"] = "Ändern Sie die Erstellung von Bytes timeseries für jeden Port des reomte Geräts, wie über ZMQ empfangen (e.g. sFlow/NetFlow/SNMP).<br>Für nicht sFlow Geräte, %%INPUT_SNMP und %%OUTPUT_SNMP müssen in der nprobe Vorlage erscheinen.",
    ["toggle_flow_rrds_title"] = "Flow Geräte",
    ["toggle_host_mask_description"] = "Aus Datenschutzgrüngen kann es notwendig sein Host IP Adressen zu maskieren. Wenn Sie beispielsweise ein ISP sind, sollten Sie nicht wissen welche lokalen Adressen auf remote Hosts zugreifen.",
    ["toggle_host_mask_title"] = "Mask Host IP Adressen",
    ["toggle_ldap_anonymous_bind_description"] = "Aktiviere anonyme binding.",
    ["toggle_ldap_anonymous_bind_title"] = "LDAP anonyme Binding",
    ["toggle_local_host_cache_enabled_description"] = "Schalten Sie auf Kreation von cache entries für idle lokale Hosts. Im Cache gespeicherte lokale Hosts werden automatisch auf ihre vorherige Werte zurückgestetzt  bei Erkennung von zusätzlichem Host Datenverkehr.",
    ["toggle_local_host_cache_enabled_title"] = "Idle Lokale Hosts Cache",
    ["toggle_logging_level_description"] = "Wählen Sie die Runtime logging Stufe.",
    ["toggle_logging_level_title"] = "Log level",
    ["toggle_mysql_check_open_files_limit_description"] = "Enable MySQL alerts generations due to periodic checks of MySQL open_files_limit.<br>The open_files_limit check is useful to detect when the number of open MySQL files is high, which could lead to database insertion errors.",
    ["toggle_mysql_check_open_files_limit_title"] = "Aktivieren Sie MySQL Warnungen",
    ["toggle_ndpi_timeseries_creation_description"] = "Schalten sie die Erstellung von Layer-7 Applikation timeseries um. Die Kreation eines timeseries pro Protokoll erfordert mehr Speicherplatz und eine zusätzliche I/O und wird im Allgemeinen nicht benötigt.",
    ["toggle_ndpi_timeseries_creation_title"] = "Layer-7 Applikationen",
    ["toggle_network_discovery_description"] = "Schalten sie die periodische Erkennung von Netzwerkgeräten mit Hilfe verschiedener Techniken die ARP scan, MDNS und SSDP beinhalten ein.",
    ["toggle_network_discovery_title"] = "Aktive Netzwerkerkennung",
    ["toggle_pools_rrds_description"] = "Schalten Sie auf Erstellung der Bytes und Anwendungsprotokolls timeseries für definierte Host pools um.",
    ["toggle_pools_rrds_title"] = "Host Pools",
    ["toggle_shaping_directions_description"] = "Aktivieren Sie diese Option um verschiedene shaping Richtlinen für den eingehenen und ausgehenden Datenverkehr festlegen zu können.",
    ["toggle_shaping_directions_title"] = "Split Shaping Richtungen",
    ["toggle_slack_notification_description"] = "Wechseln Sie die Alarmbenachrichtigung über slack. Siehe Integrationsanweisungen <a href='%{url}'>here</a>.",
    ["toggle_slack_notification_title"] = "Aktiviere <a href=\"%{url}\">Slack</a> Benachrichtigung",
    ["toggle_snmp_rrds_description"] = "Schalten Sie auf Erstellung von Bytes timeseries für jeden Port der SNMP devices ein. Für jeden device port ein RRD wird kreirt mit Eingang/Ausgang Bytes.",
    ["toggle_snmp_rrds_title"] = "SNMP Devices Timeseries",
    ["toggle_src_with_post_nat_src_description"] = "Ersetzen Sie IPv4 source Adressen (%%IPV4_SRC_ADDR) und ports (%%L4_SRC_PORT) mit deren post-nat values (%%POST_NAT_SRC_IPV4_ADDR and %%POST_NAPT_SRC_TRANSPORT_PORT).",
    ["toggle_src_with_post_nat_src_title"] = "Post-Nat Source IPv4 Adressen und Ports benutzen",
    ["toggle_thpt_content_description"] = "Wählen Sie die throughput Einheit aus die in Datenverkehrsreports angezeigt werden soll.",
    ["toggle_thpt_content_title"] = "Throughput Einheit",
    ["toggle_tiny_flows_dump_description"] = "Schalte den Export von winzigen Flows ein, das sind Flows mit wenigen Paketen oder Bytes.Reduktion der flow Kardinalität in Datenbanken verschnellert Einfügen und Durchsuchen. Tuning von winzigen Flows kann dazu beitragen die flow Kardinalität zu begrenzen ohne die Sichtbarkeit gedumpter Information zu beeinträchtigen.",
    ["toggle_tiny_flows_dump_title"] = "Tiny Flows Export",
    ["toggle_top_sites_description"] = "Schalte die Erstellung der am häufigsten besuchten Websites für lokale Hosts ein. Top Web-sites werden kreirt mit einem <a href=\"%{url}\">heuristic</a> welche nicht mehr als 20 Sites pro lokaler Host verwalten. Die Heuristik arbeitet vollständig im Speicher und erfordert keine Interaktion mit der Festplatte. Top Web-sites werden alle 5 Minuten gelöscht. Ein historisches Archiv der am häufigsten besuchten Websites kann für jeden lokalen Host erstellt werden indem die JSON regelmässig abgefragt wird <i class=\"fas fa-download fa-sm\"></i> download link welcher über die Host-Detailseite zugänglich ist.",
    ["toggle_top_sites_title"] = "Top HTTP Sites",
    ["toggle_traffic_rrd_creation_description"] = "Schalten Sie die Erstellung von timeseries für Bytes und Pakete um.",
    ["toggle_traffic_rrd_creation_title"] = "Datenverkehr",
    ["toggle_users_rrds_description"] = "Ändern Sie die Erstellung von Zeitserien für Bytes und Anwendungsprotokolle für definierte Benutzer.",
    ["toggle_users_rrds_title"] = "Users",
    ["toggle_vlan_rrds_description"] = "Schalten Sie auf Kreation der Bytes und Applikation timeseries für VLANs um.",
    ["toggle_vlan_rrds_title"] = "VLANs",
    ["topk_heuristic_precision_description"] = "Verwenden Sie eine Heuristik beim Aggregieren von historischen Top Hosts, Ländern usw, um Verkehrsberichte zu erstellen. Nützlich beim Erstellen von Berichten über lange Zeiträume.",
    ["topk_heuristic_precision_title"] = "Top-K Heuristik",
    ["traffic_bridging"] = "Datenverkehr Bridging",
    ["traffic_shaping"] = "Datenverkehrs Shaping",
    ["user_authentication"] = "Benutzer Authentifikation",
    ["user_group_description"] = "Gruppenname zu der der Benutzer gehören muss um sich als unprivilegierter Benutzer zu authentifizieren.",
    ["user_group_title"] = "LDAP Benutzergruppe",
    ["vlan"] = "VLAN Id",
    ["web_user_interface"] = "Webbenutzer Interface",
    ["zmq_interfaces"] = "ZMQ Interfaces",
  },
  ["processes_stats"] = {
    ["active_processes_title"] = "Aktive Processes: Echtzeitansicht",
    ["active_since"] = "Aktiv seit",
    ["legend"] = "Legende",
    ["lines"] = "Linien",
    ["missing_pid_name_message"] = "pid Name fehlt",
    ["no_traffic_detected"] = "Für diesen Prozess wurde kein Datenverkehr festgestellt, der Ablaufprozess ist abgelaufen oder der Prozess wurde beendet.",
    ["processes_timeline_title"] = "Processes Timeline",
    ["stack"] = "Stack",
    ["timeline"] = "Zeitlinie",
    ["top_hosts"] = "Top Hosts",
    ["top_hosts_traffic"] = "Top Hosts Datenverkehr",
    ["traffic_rcvd"] = "Rcvd Datenverkehr",
    ["traffic_sent"] = "Gesendeter Datenverkehr",
    ["type"] = "Typ",
  },
  ["report"] = {
    ["application_breakdown"] = "Applikation Ausfall",
    ["applications"] = "Applikationen",
    ["begin_date_time"] = "Beginn Datum/Zeit",
    ["date"] = "%{month}-%{day}-%{year}",
    ["end_date_time"] = "Ende Datum/Zeit",
    ["filter_report"] = "Filter Report",
    ["generate"] = "entwickeln",
    ["invalid_begin"] = "Beginn ungültig",
    ["invalid_begin_date"] = "Beginn Datum ungültig",
    ["invalid_begin_end"] = "Beginn/Ende ungültig",
    ["invalid_to"] = "Ungültig",
    ["local_networks"] = "Lokale Networks",
    ["local_remote"] = "Lokal/Remote",
    ["network_interface"] = "Netzwerk Interface",
    ["period"] = "Pause",
    ["please_check_format"] = "Bitte Format kontrollieren",
    ["please_choose_valid"] = "Bitte gültiges Beginn/Ende Datum und Zeit auswählen",
    ["please_choose_valid_date_and_time"] = "Bitte gültiges Datum und Zeit auswählen",
    ["receivers"] = "Empfänger",
    ["remote_local"] = "remote/lokal",
    ["report_for_subject"] = "Report - %{num_min} - für %{subject} startend %{dt}",
    ["reports_professional_only"] = "Reports sind nur in der Professional Version erhältlich",
    ["senders"] = "Sender",
    ["starting"] = "Startend",
    ["submit_filter"] = "Filter einreichen",
    ["toggle_all"] = "Toggle alle",
    ["top_asn"] = "Top ASN",
    ["top_countries"] = "Top Länder",
    ["top_local_hosts"] = "Top lokale Hosts",
    ["top_local_os"] = "Top lokaler OS",
    ["top_networks"] = "Top Netzwerke",
    ["top_non_local_os"] = "Top nicht-lokaler OS",
    ["top_remote_hosts"] = "Top Remote Hosts",
    ["top_talkers"] = "Top Talkers",
    ["total_traffic"] = "Total Datenverkehr",
    ["traffic_report"] = "Datenverkehr Report",
    ["use_server_timezone"] = "Verwende Server Timezone",
  },
  ["sflows_stats"] = {
    ["active_flows"] = "Aktive Flows",
    ["client_peer"] = "Client Peer",
    ["client_process"] = "Client Process",
    ["server_peer"] = "Server Peer",
    ["server_process"] = "Server Process",
    ["total_bytes"] = "Total Bytes",
  },
  ["shaping"] = {
    ["applied_to"] = "Angewendet",
    ["bandwidth_manager"] = "Bandweite Manager",
    ["confirm_delete_all_policies"] = "Wollen Sie wirklich \"%{pool_name}\" pool policies löschen",
    ["confirm_delete_policy"] = "Wollen Sie wirklich löschen",
    ["confirm_delete_shaper"] = "Wollen Sie wirklich den Sharper löschen ",
    ["daily_time"] = "Tägliche Zeit (Laufende / Quote)",
    ["daily_time_quota"] = "Tägliche Zeitquote",
    ["daily_traffic"] = "Täglicher Datenverkehr (Laufende / Quote)",
    ["daily_traffic_quota"] = "Tägliche Datenverkehrsquote",
    ["delete_all_policies"] = "Alle Policies löschen",
    ["delete_policy"] = "Policy löschen",
    ["delete_shaper"] = "Shaper löschen",
    ["for_dropping_all_traffic"] = "um den ganzen Datenverkehr droppen",
    ["for_no_shaping"] = "for no shaping",
    ["initial_clone_protocols"] = "Anfangs Protokollregeln werden geklont",
    ["initial_empty_protocols"] = "Anfangs Protokollregeln sind leer",
    ["manage_policies"] = "Manage Policies",
    ["no_quota_applied"] = "Keine Quote",
    ["no_quota_data"] = "Keine Quote gesetzt",
    ["no_quota_traffic"] = "Bisher kein Quoten bezogener Datenverkehr",
    ["no_shapers_available"] = "Shapers nicht verfügbar",
    ["note_default_pool_config"] = "Policies und Quoten gelten nur für benutzerdefinierte Hostpools. Wählen Sie einen anderen Pool aus oder erstellen Sie einen neuen <a href='%{url}'>here</a>.",
    ["note_drop_core"] = "Das Löschen einiger Kernprotokolle kann Nebenwirkungen bei anderen Protokollen haben. Wenn Sie zum Beispiel DNS blockieren,<br> werden die symbolischen Hostnamen nicht mehr aufgelöst und daher funktionier nur die Kommuniktion mit numerischen IPs.",
    ["note_quota_unlimited"] = "Setzen Sie Verkehr und Zeitquote auf 0 für unlimitierten Verkehr.",
    ["note_target_type"] = "Sie können ändern was in der Zielspalte angezeigt werden soll durch die Policy Target Type Feld in  <a href=\"%{url}\">Traffic Briding preferences</a> expert view.",
    ["note_traffic_categories"] = "Verkehrskategorien können konfiguriert werden in <a href=\"%{url}\">applications page</a>.",
    ["notes"] = "NOTIZEN",
    ["policy_from_pool"] = "Policy von pool",
    ["protocol_families"] = "Protokollfamilien",
    ["protocol_policy"] = "Datenverkehr Policy",
    ["protocols"] = "Protokolle",
    ["protocols_policies"] = "Protokolle Policies",
    ["see_quotas_here"] = "Besuchen Sie den Hostpool <a href='%{url}'>quotas page</a> for the full overview of the active host pool quotas.",
    ["select_to_clone"] = "Wählen Sie ein bestehendes Netzwerk zum Klonen der Protokollregeln aus",
    ["set_max_rate_to"] = "Maximale rate einstellen auf",
    ["shaper0_message"] = "Shaper 0 ist der Standard Sharper der für lokale Hosts verwendet wird für die kein Sharper definiert ist",
    ["shaper_id"] = "Shaper Id",
    ["shapers_in_use_message"] = "Shapers können nur gelöscht werden wenn sie nicht auf ein Netzwerk angewendet werden",
    ["traffic_from"] = "Datenverkehr von",
    ["traffic_to"] = "Datenverkehr zum",
  },
  ["show_alerts"] = {
    ["1_day"] = "1 Tag",
    ["1_hour"] = "1 Stunlang.",
    ["1_month"] = "1 Monat",
    ["1_week"] = "1 Woche",
    ["1_year"] = "1 Jahr",
    ["30_min"] = "30 Minuten",
    ["5_min"] = "5 Minuten",
    ["6_months"] = "6 Monate",
    ["alert_actions"] = "Actions",
    ["alert_counts"] = "Counts",
    ["alert_datetime"] = "Datum/Zeit",
    ["alert_description"] = "Beschreibung",
    ["alert_duration"] = "Dauer",
    ["alert_severity"] = "Schwierigkeitsgrad",
    ["alert_type"] = "Alarm Typ",
    ["alerts"] = "Alarme",
    ["alerts_are_disabled_message"] = "Alarme sind deaktiviert. Bitte preferences Seite kontrollieren um diese zu aktivieren.",
    ["alerts_to_purge"] = "Alarme endgültig Löschen",
    ["confirm_delete_alert"] = "Wollen Sie wirklich den spezifizierten Alram löschen",
    ["daily"] = "Täglich",
    ["delete_alert"] = "Alarm löschen",
    ["delete_alerts_configuration"] = "Lösche Alarmkonfiguration",
    ["delete_all"] = "Alles löschen",
    ["delete_config_btn"] = "Lösche lokale %{conf}s Common Konfiguration",
    ["delete_config_message"] = "Wollen Sie wirklich das common %{granularity} lokale Alarmkonfiguration löschen %{conf}s",
    ["detected_alerts"] = "Festgestellte Alarme",
    ["engaged"] = "Bestätigt",
    ["engaged_alerts"] = "Besetzte Alarme",
    ["explorer"] = "Erforschen",
    ["five_minutes"] = "Fünf Minuten",
    ["flow_alerts"] = "Flow Alarme",
    ["flush_data"] = "Flush Data",
    ["host_delete_config_btn"] = "Host löschen %{host} Alarmkonfiguration",
    ["host_delete_config_confirm"] = "Wollen Sie wirklich die %{granularity} Alarmkonfiguration für Host löschen",
    ["hourly"] = "Stündlich",
    ["iface_delete_config_btn"] = "Interface löschen %{iface} Konfiguration",
    ["iface_delete_config_confirm"] = "Wollen Sie wirklich die %{granularity} Alarmkonfiguration für interface löschen",
    ["in_the_selected_time_frame"] = "im ausgewählten Zeitfenster",
    ["last_day"] = "Letzter Tag",
    ["last_hour"] = "Letzte Stunde",
    ["last_minute"] = "Letzte Minute",
    ["minute"] = "Minute",
    ["network_delete_config_btn"] = "Netzwerk löschen %{network} konfigurierte Alarme",
    ["network_delete_config_confirm"] = "Wollen Sie wirklich die %{granularity} Alarmkonfiguration des Netzwerkes löschen",
    ["no_recorded_alerts_message"] = "Keine aufgezeichneten Alarme für die interface %{ifname}",
    ["older_1_day_ago"] = "älter als 1 Tag",
    ["older_1_hour_ago"] = "älter als 1 Stunde",
    ["older_1_month_ago"] = "älter als 1 Monat",
    ["older_1_week_ago"] = "älter als 1 Woche",
    ["older_1_year_ago"] = "älter als 1 Jahr",
    ["older_30_minutes_ago"] = "älter als 30 Minuten",
    ["older_5_minutes_ago"] = "älter als 5 Minuten",
    ["older_6_months_ago"] = "älter als 6 Monate",
    ["older_than"] = "älter als",
    ["past"] = "Vergangene",
    ["past_alerts"] = "Vergangene Alarme",
    ["past_flow"] = "Vergangene Flüsse",
    ["purge_num_alerts"] = "Purge [%{num_alerts} alerts]",
    ["purge_subj_alerts"] = "Lösche %{subj} Alarme",
    ["purge_subj_alerts_confirm"] = "Wollen Sie wirklich die %{subj} betroffene Alarme alle endgültig löschen ?",
    ["reset_alert_database"] = "Flush Alerts Data",
    ["reset_alert_database_message"] = "Diese Handlung entfert alle Alarme in Bezug der Daten, einschlietlsich<ul><li>Runtime alerts status</li><li>Alerts configuration</li><li>Persistent alerts SQLite storage</li></ul><br>Do you really want to proceed",
    ["startup"] = "Startup",
  },
  ["snmp"] = {
    ["bound_interface_description"] = "Eine Verbingung zwischen eine Netzwerk interface und eine SNMP interface ist nützlich um den durch ntopng überwachten Netzwerkverkehr mit dem von SNMP gemeldeteten Netzwerkverkehr zu vergleichen",
    ["no_host_discovered"] = "Kein host in %{host}/%{cidr} gefunden",
    ["note"] = "NOTIZ",
    ["snmp_device"] = "SNMP Gerät",
    ["snmp_interface"] = "SNMP Interface",
    ["view_device"] = "View Gerät",
  },
  ["snmp_page"] = {
    ["guide_snmp_page_message"] = "Besuchen Sie Seite <a href='%{url}'> SNMP</a> um diesen Host der Liste der konfigurierten SNMP Geräte hinzuzufügen.",
    ["not_configured_as_snmp_device_message"] = "Host %{host_ip} wurde nicht als SNMP Gerät konfiguriert.",
    ["showing_snmp_mib_info_default_community_message"] = "Anzeigen von SNMP MIB Informationen die mit der Standardcommunity abgerufen wurden '%{community}'",
    ["trying_to_retrive_message"] = "Versuch Host SNMP MIB mit Hilfe der Standardcommunity abzurufen '%{community}'",
    ["unable_to_retrive_snmp_default_community_message"] = "Host SNMP MIB konnte nicht mit der Standardcommunity abgerufen werden '%{community}'.",
  },
  ["sprobe_page"] = {
    ["active_memory"] = "Aktive memory",
    ["latency"] = "Latenz",
    ["processes"] = "Processes",
    ["processes_traffic_tree"] = "Processes Datenverkehr Tree",
    ["show_more_info"] = "Mouse over um die process information anzuzeigen oder doppelklicken Sie um weitere Informationen anzuzeigen.",
    ["system_interactions"] = "System Interaktionen",
    ["top_processes"] = "Top Processes",
    ["top_users"] = "Top Benutzter",
    ["tree"] = "Tree",
    ["users"] = "Benutzer",
  },
  ["top_hosts"] = {
    ["top_hosts_local"] = "Top Hosts (Lokal)",
  },
  ["topk_heuristic"] = {
    ["precision"] = {
      ["aggressive"] = "Aggressiv",
      ["disabled"] = "Deaktiviert",
      ["less_accurate"] = "Weniger genau",
      ["more_accurate"] = "Genauer",
    },
  },
  ["traffic_page"] = {
    ["l4_proto_overview"] = "L4 Protokoll Übersicht",
    ["no_traffic_observed_message"] = "Für diesen Host ist kein Datenverkehr beobachtet worden",
    ["rcvd"] = "Rcvd",
  },
  ["traffic_profiles"] = {
    ["advanced_filter_examples"] = "Fortgeschrittene Filters Beispiele",
    ["confirm_delete_profile"] = "Wollen Sie wirklich das Profil löschen",
    ["delete_profile"] = "Profil löschen",
    ["destination_network"] = "Zielnetzwerk",
    ["duplicate_profile"] = "Profilname verdoppeln",
    ["edit_traffic_profiles"] = "Edit Traffic Profiles",
    ["enter_profile_filter"] = "Profilfilter eingeben",
    ["enter_profile_name"] = "Profilname eingeben",
    ["facebook_traffic"] = "Facebook",
    ["host_http_https"] = "Host HTTP/HTTPS",
    ["host_traffic"] = "Host",
    ["http_traffic"] = "HTTP",
    ["invalid_bpf"] = "Ungültiger BPF Filter",
    ["max_profiles_num"] = "Mit dieser ntopng Version kann man nur %{maxnum} Profile kreiren. Upgrade zur enterprise Version um diese Limite zu entfernen",
    ["no_profiles"] = "Keine Profile gesetzt",
    ["note"] = "Notiz",
    ["note_0"] = "Datenverkehrsprofilnamen ermöglichen alphanumerische Zeichen, Leerzeichen und Unterstriche",
    ["note_1"] = "Datenverkehrsprofile werden auf Flows angewendet. Jeder Flow kann bis zu einem Profil haben, daher wird bei mehreren Profilübereinstimmungen nur der erste ausgewählt",
    ["profile_name"] = "Profilname",
    ["see_ndpi_protos"] = "(use %{option} um alle nDPI supportierte Protokolle zu drucken)",
    ["simple_filter_examples"] = "Einfache Filters Beispiele",
    ["source_ethernet"] = "Source MAC Adresse",
    ["traffic_between"] = "Datenverkehr zwischen Hosts",
    ["traffic_filter_bpf"] = "Datenverkehrsfilter (nBPF Format)",
    ["traffic_from_to"] = "Datenverkehr von einem zum anderen Host",
    ["traffic_profiles"] = "Traffic Profile",
  },
  ["traffic_report"] = {
    ["current_day"] = "laufender Tag ",
    ["current_month"] = "laufender Monat",
    ["current_week"] = "laufende Woche",
    ["daily"] = "täglich",
    ["header_daily"] = "täglicher Report",
    ["header_monthly"] = "monatlicher report",
    ["header_weekly"] = "wöchentlicher Report",
    ["monthly"] = "monatlich",
    ["previous_day"] = "vorheriger Tag",
    ["previous_month"] = "vorheriger Monat",
    ["previous_week"] = "vorherige Woche",
    ["weekly"] = "wöchentlich",
  },
  ["tree_map"] = {
    ["hosts_treemap"] = "Hosts TreeMap",
  },
  ["unknown_devices"] = {
    ["active_only"] = "Nur Active",
    ["all_devices"] = "Alle Geräte",
    ["assign_device_pool"] = "Gerät an einen Pool zuteilen",
    ["assign_pool"] = "Zuteilen an Pool",
    ["device_name"] = "Gerät Name",
    ["filter_devices"] = "Filter Geräte",
    ["first_seen"] = "Zuerst gesehen",
    ["inactive_only"] = "Nur inaktiv",
    ["last_seen"] = "Zuletzt gesehen",
    ["no_pools"] = "Es muss ein Host pool erstellt werden um unbekannte Geräte zuzuteilen.",
    ["select_pool"] = "Bitte wählen Sie einen Host pool aus der dropdown aus, um ihn zuzuteilen '%{mac}' an:",
    ["unassigned_devices"] = "Nicht zugewiesene Geräte",
  },
  ["user_info"] = {
    ["missing_user_name_message"] = "Benutzername fehlt",
    ["top_l4_protocols"] = "Top L4 Protokolle",
    ["top_l7_protocols"] = "Top L7 Protokolle",
  },
  ["users"] = {
    ["add_new_user"] = "Neuen User hinzufügen",
    ["add_user"] = "User hinzufügen",
    ["assigned_devices"] = "Zugewiesene Geräte",
    ["categories"] = "Kategorien",
    ["confirm_delete_user"] = "Wollen Sie wirklich den angeführten User löschen \"%{user}\"?",
    ["delete_user"] = "User löschen",
    ["devices"] = "Geräte",
    ["edit"] = "Editieren",
    ["edit_global_policies"] = "Standardregeln editieren",
    ["fallback_policy"] = "Fallback Regeln",
    ["full_name"] = "Ganzer Name",
    ["global"] = "Global",
    ["global_policies"] = "Standardregeln",
    ["no_users"] = "Keine User",
    ["policy"] = "Regel",
    ["protocols"] = "Protokolle",
    ["settings"] = "Einstellungen",
    ["total_daily_time_quota"] = "Gesamtdauer der täglichen Zeit",
    ["total_daily_traffic_quota"] = "Gesamtmenge des täglichen Traffic",
    ["unchanged"] = "Unverändert",
    ["user_exists"] = "User \"%{user}\" existiert bereits",
    ["user_x"] = "User: %{user}",
    ["shapers"] = {
      ["default"] = "Standard",
      ["drop"] = "Drop",
      ["pass"] = "Pass",
      ["slow"] = "Slow Pass",
      ["slower"] = "Slower Pass",
    },
  },
  ["vlan_details"] = {
    ["no_available_stats_for_vlan_message"] = "Keine verfügbaren stats für VLAN %{vlan_id}. Bitte warten Sie einige Minuten um %{product} zu erlauben neue Statistiken zu erfassen.",
    ["vlan_id_parameter_missing_or_invalid_message"] = "Vlan_Id Parameter fehlt oder ist ungültig",
  },
  ["vlan_stats"] = {
    ["vlan_id"] = "VLAN ID",
    ["vlans"] = "VLANs",
  },
}

return lang
